/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt.c
* Description : Interrupt Handlers
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include <machine.h>
#include "iodefine.h"
#include "r_mtr_ics.h"
#include "r_mtr_foc_control_encd_position.h"
#include "r_mtr_driver_access.h"

/***********************************************************************************************************************
* Exported global variables
***********************************************************************************************************************/
mtr_foc_control_t g_st_foc;

/***********************************************************************************************************************
* Function Name : mtr_over_current_interrupt
* Description   : POE interrupt
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_over_current_interrupt(vect = VECT_POE_OEI1))
static void mtr_over_current_interrupt(void)
{
    mtr_over_current(&g_st_foc);
} /* End of function mtr_over_current_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_hall_u_interrupt
* Description   : U phase hall sensor interrupt(IRQ0)
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_hall_u_interrupt(vect = VECT_ICU_IRQ0))
static void mtr_hall_u_interrupt(void)
{
clrpsw_i();
    mtr_angle_adj_hall_interrupt(&g_st_foc);
setpsw_i();
} /* End of function mtr_hall_u_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_hall_v_interrupt
* Description   : V phase hall sensor interrupt(IRQ1)
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_hall_v_interrupt(vect = VECT_ICU_IRQ1))
static void mtr_hall_v_interrupt(void)
{
clrpsw_i();
    mtr_angle_adj_hall_interrupt(&g_st_foc);
setpsw_i();
} /* End of function mtr_hall_v_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_hall_w_interrupt
* Description   : W phase hall sensor interrupt(IRQ4)
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_hall_w_interrupt(vect = VECT_ICU_IRQ4))
static void mtr_hall_w_interrupt(void)
{
clrpsw_i();
    mtr_angle_adj_hall_interrupt(&g_st_foc);
setpsw_i();
} /* End of function mtr_hall_w_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_encd_timer_cap_interrupt
* Description   : MTU0.TGRB input capture interrupt
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_encd_timer_cap_interrupt(vect = VECT_MTU0_TGIB0))
static void mtr_encd_timer_cap_interrupt(void)
{
setpsw_i();
    mtr_encd_pos_speed_calc_interrupt(&g_st_foc);
} /* End of function mtr_encd_timer_cap_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_1ms_interrupt
* Description   : CMT0 interrupt (Period: 1ms)
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_1ms_interrupt(vect = VECT_CMT0_CMI0))
static void mtr_1ms_interrupt(void)
{
    R_MTR_AutoSetVariables();
    mtr_foc_interrupt_1ms(&g_st_foc);
} /* End of function mtr_1ms_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_100us_interrupt
* Description   : MTU3_4 interrupt (Period: 100 [us])
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_100us_interrupt(vect = VECT_MTU4_TCIV4))
static void mtr_100us_interrupt(void)
{
    mtr_foc_interrupt_carrier(&g_st_foc);
    mtr_ics_interrupt_process();
} /* End of function mtr_100us_interrupt */
