/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_ctrl_encoder.c
* Description : Processes of encoder control
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Standard library headers */
#include <math.h>
#include <machine.h>
#include <stdint.h>

/* Main associated header file */
#include "r_mtr_ctrl_encoder.h"

/* Main associated header file */
#include "iodefine.h"
#include "r_mtr_filter.h"
#include "r_mtr_common.h"
#include "r_mtr_parameter.h"
#include "r_mtr_ctrl_mcu.h"

/***********************************************************************************************************************
* Function Name : mtr_encoder_init
* Description   : Initialize variables when encoder control init
* Arguments     : st_ec               - encoder structure (pointer)
* Return Value  : None
***********************************************************************************************************************/
void mtr_encoder_init(mtr_encoder_t *st_ec)
{
    /* initialize of encoder variables */
    st_ec->u1_encd_angle_adj_status    = MTR_ENCD_ANGLE_ADJ_90DEG;
    st_ec->u2_encd_angle_adj_time      = MTR_ENCD_ANGLE_ADJ_TIME;
    st_ec->u2_encd_angle_adj_cnt       = 0;
    st_ec->u2_encd_pre_phase_cnt       = 0;
    st_ec->u2_encd_timer_cap_tcnt      = 0;
    st_ec->u2_encd_timer_cap_pre_tcnt  = 0;
    st_ec->u2_encd_timer_cnt_num       = 0;
    st_ec->u2_encd_cpr_mech            = MTR_ENCD_CPR_MECH;
    st_ec->s4_encd_timer_cnt_buff[0]   = 0;
    st_ec->s4_encd_timer_cnt_buff[1]   = 0;
    st_ec->s4_encd_timer_cnt_buff[2]   = 0;
    st_ec->s4_encd_timer_cnt_buff[3]   = 0;
    st_ec->s4_encd_pulse_width         = 0;
    st_ec->s4_encd_pulse_width_buff    = 0;
    st_ec->s4_encd_pulse_width_sum     = 0;
    st_ec->s4_encd_angle_cnt           = 0;
    st_ec->f4_encd_angle_diff          = MTR_ENCD_ANGLE_DIFF;
    st_ec->f4_encd_cpr_mech_inv        = 1.0f / (float)MTR_ENCD_CPR_MECH;
    st_ec->f4_encd_speed_pre_rad       = 0.0f;
    st_ec->f4_encd_speed_rad           = 0.0f;
    st_ec->f4_encd_pos_rad             = 0.0f;
} /* End of function mtr_encoder_init */

/***********************************************************************************************************************
* Function Name : mtr_encoder_reset
* Description   : Reset variables when encoder control
* Arguments     : st_ec               - encoder structure (pointer)
* Return Value  : None
***********************************************************************************************************************/
void mtr_encoder_reset(mtr_encoder_t *st_ec)
{
    st_ec->u1_encd_angle_adj_status    = MTR_ENCD_ANGLE_ADJ_90DEG;
    st_ec->u2_encd_angle_adj_time      = MTR_ENCD_ANGLE_ADJ_TIME;
    st_ec->u2_encd_angle_adj_cnt       = 0;
    st_ec->u2_encd_pre_phase_cnt       = 0;
    st_ec->u2_encd_timer_cap_tcnt      = 0;
    st_ec->u2_encd_timer_cap_pre_tcnt  = 0;
    st_ec->u2_encd_timer_cnt_num       = 0;
    st_ec->s4_encd_angle_cnt           = 0;
    st_ec->s4_encd_timer_cnt_buff[0]   = 0;
    st_ec->s4_encd_timer_cnt_buff[1]   = 0;
    st_ec->s4_encd_timer_cnt_buff[2]   = 0;
    st_ec->s4_encd_timer_cnt_buff[3]   = 0;
    st_ec->s4_encd_pulse_width         = 0;
    st_ec->s4_encd_pulse_width_buff    = 0;
    st_ec->s4_encd_pulse_width_sum     = 0;
    st_ec->s4_encd_angle_cnt           = 0;
    st_ec->f4_encd_pos_rad             = 0.0f;
    st_ec->f4_encd_speed_pre_rad       = 0.0f;
    st_ec->f4_encd_speed_rad           = 0.0f;
} /* End of function mtr_encoder_reset */

/***********************************************************************************************************************
* Function Name : mtr_encoder_highspeed_init
* Description   : Initialize variables when motor control start
* Arguments     : st_ehc              - encoder highspeed structure (pointer)
* Return Value  : None
***********************************************************************************************************************/
void mtr_encoder_highspeed_init(mtr_encoder_highspeed_t *st_ehc)
{
    st_ehc->u1_encd_pos_speed_calc_mode = MTR_PS_CALC_ENCD_INTERRUPT;
    st_ehc->u1_encd_interrupt_on_flag   = MTR_FLG_CLR;
    st_ehc->u1_encd_pos_speed_calc_cnt  = 0;
    st_ehc->s4_encd_hs_angle_cnt        = 0;
    st_ehc->u2_encd_hs_pre_phase_cnt    = 0;
    st_ehc->f4_encd_hs_pos_rad          = 0.0f;
    st_ehc->f4_encd_hs_pos_pre_rad      = 0.0f;
    st_ehc->f4_encd_hs_speed_rad        = 0.0f;
    st_ehc->f4_encd_hs_speed_pre_rad    = 0.0f;
    st_ehc->f4_encd_hs_sw_speed_rad     = MTR_HS_CHANGE_RAD;
    st_ehc->f4_encd_hs_sw_speed_margin_rad = MTR_HS_CHANGE_MARGIN_RAD;
} /* End of function mtr_encoder_highspeed_init */

/***********************************************************************************************************************
* Function Name : mtr_encoder_highspeed_reset
* Description   : Reset variables when motor control start
* Arguments     : st_ehc              - encoder highspeed structure (pointer)
* Return Value  : None
***********************************************************************************************************************/
void mtr_encoder_highspeed_reset(mtr_encoder_highspeed_t *st_ehc)
{
    st_ehc->u1_encd_pos_speed_calc_mode = MTR_PS_CALC_ENCD_INTERRUPT;
    st_ehc->u1_encd_interrupt_on_flag   = MTR_FLG_CLR;
    st_ehc->u1_encd_pos_speed_calc_cnt  = 0;
    st_ehc->s4_encd_hs_angle_cnt        = 0;
    st_ehc->u2_encd_hs_pre_phase_cnt    = 0;
    st_ehc->f4_encd_hs_pos_rad          = 0.0f;
    st_ehc->f4_encd_hs_pos_pre_rad      = 0.0f;
    st_ehc->f4_encd_hs_speed_rad        = 0.0f;
    st_ehc->f4_encd_hs_speed_pre_rad    = 0.0f;
} /* End of function mtr_encoder_highspeed_reset */

/***********************************************************************************************************************
* Function Name : mtr_set_param_encd_cpr_mech
* Description   : Set related parameters to encoder (quad edge evaluation)
* Arguments     : st_ec               - encoder structure (pointer)
*                 u2_encd_cpr_mech    - encoder pulse (quad edge evaluation)
* Return Value  : None
***********************************************************************************************************************/
void mtr_set_param_encd_cpr_mech(mtr_encoder_t *st_ec, uint16_t u2_encd_cpr_mech)
{
    /* encoder counts per revolution (mechanical) */
    st_ec->u2_encd_cpr_mech = u2_encd_cpr_mech;
    /* inverse number of encoder counts per revolution (mechanical) */
    st_ec->f4_encd_cpr_mech_inv = 1.0f / (float)st_ec->u2_encd_cpr_mech;
    /* angle of encoder 1 pulse width */
    st_ec->f4_encd_angle_diff = MTR_TWOPI * st_ec->f4_encd_cpr_mech_inv;
} /* End of function mtr_set_param_encd_cpr_mech */

/***********************************************************************************************************************
* Function Name : mtr_set_param_encd_hs_sw_speed_rad
* Description   : Set toggle speed for high speed mode
* Arguments     : st_ehc                   - encoder highspeed structure (pointer)
*                 f4_encd_hs_sw_speed_rpm  - toggle speed for high speed mode [rpm]
*                 f4_rpm_rad               - rpm to rad
* Return Value  : None
***********************************************************************************************************************/
void mtr_set_param_encd_hs_sw_speed_rad(mtr_encoder_highspeed_t *st_ehc,
                                        uint16_t u2_encd_hs_sw_speed_rpm,
                                        float f4_rpm_rad)
{
    st_ehc->f4_encd_hs_sw_speed_rad = (float)u2_encd_hs_sw_speed_rpm * f4_rpm_rad;
} /* End of function mtr_set_param_encd_hs_sw_speed_rad */

/***********************************************************************************************************************
* Function Name : mtr_set_param_encd_hs_sw_speed_margin_rad
* Description   : Set margin of toggle speed for high speed mode [rad/s]
* Arguments     : st_ehc                         - encoder highspeed structure (pointer)
*                 f4_encd_hs_sw_speed_margin_rpm - margin of toggle speed for high speed mode [rpm]
*                 f4_rpm_rad                     - rpm to rad
* Return Value  : None
***********************************************************************************************************************/
void mtr_set_param_encd_hs_sw_speed_margin_rad(mtr_encoder_highspeed_t *st_ehc,
                                               uint16_t u2_encd_hs_sw_speed_margin_rpm,
                                               float f4_rpm_rad)
{
    st_ehc->f4_encd_hs_sw_speed_margin_rad = (float)u2_encd_hs_sw_speed_margin_rpm * f4_rpm_rad;
} /* End of function mtr_set_param_encd_hs_sw_speed_margin_rad */

/***********************************************************************************************************************
* Function Name : mtr_get_encd_tcnt
* Description   : Get encoder timer count
* Arguments     : u1_id - The motor ID which specify the motor connectors
* Return Value  : Encoder timer count
***********************************************************************************************************************/
uint16_t mtr_get_encd_tcnt(uint8_t u1_id)
{
    uint16_t u2_temp;

    switch (u1_id)
    {
        case MTR_ID_A:
            u2_temp = MTR_ENCD_TCNT;
        break;

        default:
            /* Do Nothing */
        break;
    }

    return (u2_temp);
} /* End of function mtr_get_encd_tcnt */

/***********************************************************************************************************************
* Function Name : mtr_set_encd_tcnt
* Description   : Set encoder timer
* Arguments     : u1_id          - Motor ID
*                 u2_cnt_value   - count
* Return Value  : None
***********************************************************************************************************************/
void mtr_set_encd_tcnt(uint8_t u1_id, uint16_t u2_cnt_value)
{
    switch (u1_id)
    {
        case MTR_ID_A:
            MTR_ENCD_TCNT = u2_cnt_value;
        break;

        default:
            /* Do Nothing */
        break;
    }
} /* End of function mtr_set_encd_tcnt */

/***********************************************************************************************************************
* Function Name : mtr_encd_cnt_reset
* Description   : Encoder count reset
* Arguments     : st_ec               - encoder structure (pointer)
*                 u1_id - The motor ID which specify the motor connectors
* Return Value  : None
***********************************************************************************************************************/
void mtr_encd_cnt_reset(mtr_encoder_t *st_ec, uint8_t u1_id)
{
    switch (u1_id)
    {
        case MTR_ID_A:
            /* reset structure members */
            st_ec->s4_encd_angle_cnt     = 0;
            st_ec->u2_encd_pre_phase_cnt = 0;
            /* reset timer counter */
            mtr_set_encd_tcnt(u1_id, 0);
        break;

        default:
            /* Do Nothing */
        break;
    }
} /* End of function mtr_encd_cnt_reset */

/***********************************************************************************************************************
* Function Name : mtr_angle_adj_excit
* Description   : Angle adjust with forced excitation
* Arguments     : st_ec - encoder structure (pointer)
*                 u1_id - The motor ID which specify the motor connectors
* Return Value  : command value of id
***********************************************************************************************************************/
void mtr_angle_adj_excit(mtr_encoder_t *st_ec, uint8_t u1_id)
{
    /* angle adjusted to 90 degree */
    if (MTR_ENCD_ANGLE_ADJ_90DEG == st_ec->u1_encd_angle_adj_status)
    {
        /* reset angle adjust counter */
        st_ec->u2_encd_angle_adj_cnt = 0;
        st_ec->u1_encd_angle_adj_status = MTR_ENCD_ANGLE_ADJ_0DEG;
    }
    /* angle adjusted to 0 degree */
    else if (MTR_ENCD_ANGLE_ADJ_0DEG == st_ec->u1_encd_angle_adj_status)
    {
clrpsw_i();
        /* reset timer counter */
        mtr_set_encd_tcnt(u1_id, 0);
        /* reset encoder counter */
        mtr_encd_cnt_reset(st_ec, u1_id);
setpsw_i();
        mtr_speed_calc_timer_start(u1_id);
        /* prevent angle adjust count overflow (not necessary,TBD)*/
        st_ec->u2_encd_angle_adj_cnt = st_ec->u2_encd_angle_adj_time;
        st_ec->u1_encd_angle_adj_status = MTR_ENCD_ANGLE_ADJ_FIN;
    }
    else
    {
        /* Do Nothing */
    }
} /* End of function mtr_angle_adj_excit */

/***********************************************************************************************************************
* Function Name : mtr_encd_hs_cnt_diff
* Description   : Enncoder count difference calculation 
* Arguments     : st_ehc - encoder highspeed structure (pointer)
*                 u1_id  - The motor ID which specify the motor connectors
* Return Value  : None 
***********************************************************************************************************************/
void mtr_encd_hs_cnt_diff(mtr_encoder_highspeed_t *st_ehc, uint8_t u1_id)
{
    uint16_t u2_temp;
    int16_t  s2_encd_delta_tcnt;

    u2_temp = mtr_get_encd_tcnt(u1_id);
    s2_encd_delta_tcnt = st_ehc->u2_encd_hs_pre_phase_cnt - u2_temp;
    st_ehc->s4_encd_hs_angle_cnt += (int32_t)s2_encd_delta_tcnt;
    st_ehc->u2_encd_hs_pre_phase_cnt = u2_temp;
} /* End of function mtr_encd_hs_cnt_diff */

/***********************************************************************************************************************
* Function Name : mtr_encd_hs_speed_calc
* Description   : Calculate speed
* Arguments     : st_ehc         - encoder highspeed structure (pointer)
*                 f4_pos_err     - position error [rad]
*                 f4_ctrl_period - control period
* Return Value  : None 
***********************************************************************************************************************/
void mtr_encd_hs_speed_calc(mtr_encoder_highspeed_t *st_ehc, float f4_pos_err, float f4_ctrl_period)
{
    float    f4_temp_speed_rad;

    f4_temp_speed_rad = f4_pos_err / f4_ctrl_period;
    st_ehc->f4_encd_hs_pos_pre_rad = st_ehc->f4_encd_hs_pos_rad;
    st_ehc->f4_encd_hs_speed_rad = R_MTR_Lpff(f4_temp_speed_rad,
                                              st_ehc->f4_encd_hs_speed_pre_rad,
                                              MTR_HS_SPEED_LPF_PARAM);
    st_ehc->f4_encd_hs_speed_pre_rad = st_ehc->f4_encd_hs_speed_rad;
} /* End of function mtr_encd_hs_speed_calc */

/***********************************************************************************************************************
* Function Name : mtr_encd_hs_switch_encd_interrupt
* Description   : Switch interrupt process of encoder interrupt
* Arguments     : st_ehc              - encoder highspeed structure (pointer)
*                 f4_speed_rad        - speed [rad/s]
*                 u1_id - The motor ID which specify the motor connectors
* Return Value  : None 
***********************************************************************************************************************/
void mtr_encd_hs_switch_encd_interrupt(mtr_encoder_highspeed_t *st_ehc, float f4_speed_rad, uint8_t u1_id)
{
    float f4_temp;

    f4_temp = st_ehc->f4_encd_hs_sw_speed_rad - st_ehc->f4_encd_hs_sw_speed_margin_rad;
    if (f4_temp > fabsf(f4_speed_rad))
    {
clrpsw_i();
        mtr_encd_interrupt_enable(u1_id);
setpsw_i();
        st_ehc->u1_encd_interrupt_on_flag = MTR_FLG_SET;
        st_ehc->u1_encd_pos_speed_calc_cnt++;
        if(st_ehc->u1_encd_pos_speed_calc_cnt >= MTR_PS_CALC_CHANGE_CNT)
        {
            st_ehc->u1_encd_pos_speed_calc_mode = MTR_PS_CALC_ENCD_INTERRUPT;
            st_ehc->u1_encd_pos_speed_calc_cnt = 0;
        }
    }
    else
    {
clrpsw_i();
        mtr_encd_interrupt_disable(u1_id);
setpsw_i();
    }
} /* End of function mtr_encd_hs_switch_encd_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_encd_hs_switch_ctrl_interrupt
* Description   : Switch carrier innterupt process
* Arguments     : st_ehc              - encoder highspeed structure (pointer)
*                 f4_speed_rad        - speed [rad/s]
*                 u1_id - The motor ID which specify the motor connectors
* Return Value  : None 
***********************************************************************************************************************/
void mtr_encd_hs_switch_ctrl_interrupt(mtr_encoder_highspeed_t *st_ehc, float f4_speed_rad, uint8_t u1_id)
{
    if (st_ehc->f4_encd_hs_sw_speed_rad <= fabsf(f4_speed_rad))
    {
        st_ehc->u1_encd_pos_speed_calc_mode = MTR_PS_CALC_CTRL_INTERRUPT;
        st_ehc->u1_encd_pos_speed_calc_cnt = 0;
clrpsw_i();
        mtr_encd_interrupt_disable(u1_id);
setpsw_i();
    }
} /* End of function mtr_encd_hs_switch_ctrl_interrupt */
