/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt_1ms.c
* Description : The 1ms interval interrupt handler of FOC
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Standard library headers */
#include <stdint.h>
#include <machine.h>
#include <math.h>

/* Main associated header file */
#include "r_mtr_foc_control_encd_position.h"

/* Project headers */
#include "r_mtr_common.h"
#include "r_mtr_parameter.h"
#include "r_mtr_ctrl_mcu.h"

/***********************************************************************************************************************
* Function Name : mtr_foc_interrupt_1ms
* Description   : 1ms interrupt handler of FOC control
* Arguments     : st_foc - The pointer to the FOC data structure
* Return Value  : None
***********************************************************************************************************************/
void mtr_foc_interrupt_1ms(mtr_foc_control_t *st_foc)
{
    /*====================*/
    /*   set reference    */
    /*====================*/
    if (MTR_MODE_ACTIVE == mtr_statemachine_get_status(&st_foc->st_stm))
    {
        /***** decide direction *****/
        mtr_decide_direction(st_foc);

        /***** Id, Iq, speed reference setting *****/
        switch (st_foc->u2_run_mode)
        {
            case MTR_MODE_INIT:
                if (MTR_FLG_SET == st_foc->u1_flag_offset_calc)
                {
                    if (MTR_ANGLE_ADJ_HALL == st_foc->u1_encd_angle_adj_mode)
                    {
                        st_foc->st_hc.f4_hall_angle_rad = mtr_angle_adj_hall_init(&st_foc->st_hc);
                        mtr_hall_error(st_foc, st_foc->st_hc.f4_hall_angle_rad);
clrpsw_i();
                        /* reset encoder counter and timer */
                        mtr_encd_cnt_reset(&st_foc->st_ec, st_foc->u1_id);
setpsw_i();
                        mtr_speed_calc_timer_start(st_foc->u1_id);              /* timer start */
                        mtr_irq_interrupt_enable(st_foc->u1_id);                /* hall interrupt enable */
                        st_foc->st_ec.u1_encd_angle_adj_status = MTR_ENCD_ANGLE_ADJ_FIN;
                        st_foc->u2_run_mode = MTR_MODE_DRIVE;
                    }
                    else
                    {
                        st_foc->u2_run_mode = MTR_MODE_BOOT;
                    }
                }
            break;

            case MTR_MODE_BOOT:
                st_foc->st_pc.f4_ref_pos_rad_ctrl = mtr_set_pos_ref(st_foc);
                st_foc->st_sc.f4_ref_speed_rad_ctrl = mtr_set_speed_ref(st_foc);
                st_foc->st_cc.f4_iq_ref = mtr_set_iq_ref(st_foc);
                st_foc->st_cc.f4_id_ref = mtr_set_id_ref(st_foc);
                if (MTR_ENCD_ANGLE_ADJ_FIN == st_foc->st_ec.u1_encd_angle_adj_status)
                {
                    st_foc->u2_run_mode = MTR_MODE_DRIVE;
                }
            break;

            case MTR_MODE_DRIVE:
                st_foc->st_pc.f4_ref_pos_rad_ctrl = mtr_set_pos_ref(st_foc);
                st_foc->st_sc.f4_ref_speed_rad_ctrl = mtr_set_speed_ref(st_foc);
                st_foc->st_cc.f4_iq_ref = mtr_set_iq_ref(st_foc);
                st_foc->st_cc.f4_id_ref = mtr_set_id_ref(st_foc);
            break;

            default:
                /* Do Nothing */
            break;
        }
    }
} /* End of function mtr_foc_interrupt_1ms */
