/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_ctrl_mrssk.c
* Description : Processes of a H/W control layer(Inverter board dependence)
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include <stdint.h>
#include <machine.h>
#include "r_mtr_ctrl_mrssk.h"
#include "iodefine.h"
#include "r_mtr_common.h"
#include "r_mtr_ctrl_mcu.h"

/***********************************************************************************************************************
* Function Name : get_vr1
* Description   : Get A/D converted value of VR1
* Arguments     : None
* Return Value  : A/D converted value of VR1
***********************************************************************************************************************/
uint16_t get_vr1(void)
{
    uint16_t ad_data;

    ad_data = mtr_get_vr1_adc();                        /* Read from VR1 */

    return (ad_data);
} /* End of function get_vr1 */

/***********************************************************************************************************************
* Function Name : get_sw1
* Description   : Get state of SW1
* Arguments     : None
* Return Value  : State of SW1
***********************************************************************************************************************/
uint8_t get_sw1(void)
{
    uint8_t tmp_port;

    tmp_port = MTR_PORT_SW1;

    return (tmp_port);
} /* End of function get_sw1 */

/***********************************************************************************************************************
* Function Name : get_sw2
* Description   : Get state of SW2
* Arguments     : None
* Return Value  : State of SW2
***********************************************************************************************************************/
uint8_t get_sw2(void)
{
    uint8_t tmp_port;

    tmp_port = MTR_PORT_SW2;

    return (tmp_port);
} /* End of function get_sw2 */

/***********************************************************************************************************************
* Function Name : led1_on
* Description   : Turn on LED1
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led1_on(void)
{
    MTR_PORT_LED1 = MTR_LED_ON;
} /* End of function led1_on */

/***********************************************************************************************************************
* Function Name : led2_on
* Description   : Turn on LED2
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led2_on(void)
{
    MTR_PORT_LED2 = MTR_LED_ON;
} /* End of function led2_on */

/***********************************************************************************************************************
* Function Name : led3_on
* Description   : Turn on LED3
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led3_on(void)
{
    MTR_PORT_LED3 = MTR_LED_ON;
} /* End of function led3_on */

/***********************************************************************************************************************
* Function Name : led1_off
* Description   : Turn off LED1
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led1_off(void)
{
    MTR_PORT_LED1 = MTR_LED_OFF;
} /* End of function led1_off */

/***********************************************************************************************************************
* Function Name : led2_off
* Description   : Turn off LED2
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led2_off(void)
{
    MTR_PORT_LED2 = MTR_LED_OFF;
} /* End of function led2_off */

/***********************************************************************************************************************
* Function Name : led3_off
* Description   : Turn off LED3
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void led3_off(void)
{
    MTR_PORT_LED3 = MTR_LED_OFF;
} /* End of function led3_off */

/***********************************************************************************************************************
* Function Name : mtr_get_vdc
* Description   : Get Vdc
* Arguments     : u1_id - Motor ID
* Return Value  : Vdc value
***********************************************************************************************************************/
float mtr_get_vdc(uint8_t u1_id)
{
    float f4_temp_vdc;

    switch (u1_id)
    {
        case MTR_ID_A:
            f4_temp_vdc = mtr_get_vdc_adc(u1_id);
            f4_temp_vdc = f4_temp_vdc * MTR_VDC_SCALING;             /* Vdc */
        break;

        default:
            /* Do Nothing */
        break;
    }

    return (f4_temp_vdc);
} /* End of function mtr_get_vdc */

/***********************************************************************************************************************
* Function Name : mtr_get_current_iuiw
* Description   : Get current
* Arguments     : f4_iu_ad - U phase current A/D conversion value (pointer)
*                 f4_iw_ad - W phase current A/D conversion value (pointer)
*                 u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_get_current_iuiw(float *f4_iu_ad, float *f4_iw_ad, uint8_t u1_id)
{
    float f4_temp_iu;
    float f4_temp_iw;

    switch (u1_id)
    {
        case MTR_ID_A:
            mtr_get_current_adc(&f4_temp_iu, &f4_temp_iw, u1_id);

            f4_temp_iu = f4_temp_iu - MTR_ADC_OFFSET;
            f4_temp_iw = f4_temp_iw - MTR_ADC_OFFSET;

            *f4_iu_ad = (- f4_temp_iu) * MTR_CURRENT_SCALING;      /* U-phase current */
            *f4_iw_ad = (- f4_temp_iw) * MTR_CURRENT_SCALING;      /* W-phase current */
        break;

        default:
            /* Do Nothing */
        break;
    }
} /* End of function mtr_get_current_iuiw */
