/*************************************************************************************************************************
*
* Device     : RX/RX200/RX23T
*
* File Name  : iodefine.h
*
* Abstract   : Definition of I/O Register.
*
* History    : 0.5  (2014-11-07)  [Hardware Manual Revision : 0.50]
*            : 0.5A (2014-11-13)  [Hardware Manual Revision : 0.50]
*            : 1.0  (2015-04-23)  [Hardware Manual Revision : 1.00]
*            : 1.1  (2015-07-13)  [Hardware Manual Revision : 1.10]
*            : 1.1A (2016-08-24)  [Hardware Manual Revision : 1.10]
*
* NOTE       : THIS IS A TYPICAL EXAMPLE.
*
* Copyright (C) 2016 (2014 - 2015) Renesas Electronics Corporation.
*
*************************************************************************************************************************/
/************************************************************************************************************************/
/*                                                                              */
/*  DESCRIPTION : Definition of ICU Register                                    */
/*  CPU TYPE    : RX23T                                                         */
/*                                                                              */
/*  Usage : IR,DTCER,IER,IPR of ICU Register                                    */
/*     The following IR, DTCE, IEN, IPR macro functions simplify usage.         */
/*     The bit access operation is "Bit_Name(interrupt source,name)".           */
/*     A part of the name can be omitted.                                       */
/*     for example :                                                            */
/*       IR(MTU0,TGIA0) = 0;     expands to :                                   */
/*         ICU.IR[114].BIT.IR = 0;                                              */
/*                                                                              */
/*       DTCE(ICU,IRQ0) = 1;     expands to :                                   */
/*         ICU.DTCER[64].BIT.DTCE = 1;                                          */
/*                                                                              */
/*       IEN(CMT0,CMI0) = 1;     expands to :                                   */
/*         ICU.IER[0x03].BIT.IEN4 = 1;                                          */
/*                                                                              */
/*       IPR(MTU1,TGIA1) = 2;    expands to :                                   */
/*       IPR(MTU1,TGI  ) = 2;    // TGIA1,TGIB1 share IPR level.                */
/*         ICU.IPR[121].BIT.IPR = 2;                                            */
/*                                                                              */
/*       IPR(SCI1,ERI1) = 3;     expands to :                                   */
/*       IPR(SCI1,    ) = 3;     // SCI1 uses single IPR for all sources.       */
/*         ICU.IPR[218].BIT.IPR = 3;                                            */
/*                                                                              */
/*  Usage : #pragma interrupt Function_Identifier(vect=**)                      */
/*     The number of vector is "(interrupt source, name)".                      */
/*     for example :                                                            */
/*       #pragma interrupt INT_IRQ0(vect=VECT(ICU,IRQ0))          expands to :  */
/*         #pragma interrupt INT_IRQ0(vect=64)                                  */
/*       #pragma interrupt INT_CMT0_CMI0(vect=VECT(CMT0,CMI0))    expands to :  */
/*         #pragma interrupt INT_CMT0_CMI0(vect=28)                             */
/*       #pragma interrupt INT_MTU0_TGIA0(vect=VECT(MTU0,TGIA0))  expands to :  */
/*         #pragma interrupt INT_MTU0_TGIA0(vect=114)                           */
/*                                                                              */
/*  Usage : MSTPCRA,MSTPCRB,MSTPCRC of SYSTEM Register                          */
/*     The bit access operation is "MSTP(name)".                                */
/*     The name that can be used is a macro name defined with "iodefine.h".     */
/*     for example :                                                            */
/*       MSTP(TMR2) = 0;    // TMR2,TMR3,TMR23                    expands to :  */
/*         SYSTEM.MSTPCRA.BIT.MSTPA4  = 0;                                      */
/*       MSTP(MTU4) = 0;    // MTU,MTU0,MTU1,MTU2,MTU3,MTU4,MTU5  expands to :  */
/*         SYSTEM.MSTPCRA.BIT.MSTPA9  = 0;                                      */
/*       MSTP(CMT3) = 0;    // CMT2,CMT3                          expands to :  */
/*         SYSTEM.MSTPCRA.BIT.MSTPA14 = 0;                                      */
/*                                                                              */
/*                                                                              */
/************************************************************************************************************************/
#ifndef __RX23TIODEFINE_HEADER__
#define __RX23TIODEFINE_HEADER__
#pragma bit_order left
#pragma unpack
struct st_bsc {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char STSCLR:1;
        } BIT;
    } BERCLR;
    char           wk0[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TOEN:1;
            unsigned char IGAEN:1;
        } BIT;
    } BEREN;
    char           wk1[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char MST:3;
            unsigned char :2;
            unsigned char TO:1;
            unsigned char IA:1;
        } BIT;
    } BERSR1;
    char           wk2[1];
    union {
        unsigned short WORD;
        struct {
            unsigned short ADDR:13;
            unsigned short :3;
        } BIT;
    } BERSR2;
    char           wk3[4];
    union {
        unsigned short WORD;
        struct {
            unsigned short :4;
            unsigned short BPFB:2;
            unsigned short BPHB:2;
            unsigned short BPGB:2;
            unsigned short BPIB:2;
            unsigned short BPRO:2;
            unsigned short BPRA:2;
        } BIT;
    } BUSPRI;
};

struct st_cac {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char CFME:1;
        } BIT;
    } CACR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char EDGES:2;
            unsigned char TCSS:2;
            unsigned char FMCS:3;
            unsigned char CACREFE:1;
        } BIT;
    } CACR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char DFS:2;
            unsigned char RCDS:2;
            unsigned char RSCS:3;
            unsigned char RPS:1;
        } BIT;
    } CACR2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char OVFFCL:1;
            unsigned char MENDFCL:1;
            unsigned char FERRFCL:1;
            unsigned char :1;
            unsigned char OVFIE:1;
            unsigned char MENDIE:1;
            unsigned char FERRIE:1;
        } BIT;
    } CAICR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char OVFF:1;
            unsigned char MENDF:1;
            unsigned char FERRF:1;
        } BIT;
    } CASTR;
    char           wk0[1];
    unsigned short CAULVR;
    unsigned short CALLVR;
    unsigned short CACNTBR;
};

struct st_cmpc0 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char HCMPON:1;
            unsigned char CDFS:2;
            unsigned char CEG:2;
            unsigned char :1;
            unsigned char COE:1;
            unsigned char CINV:1;
        } BIT;
    } CMPCTL;
    char           wk0[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char CMPSEL:4;
        } BIT;
    } CMPSEL0;
    char           wk1[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char CVRS:2;
        } BIT;
    } CMPSEL1;
    char           wk2[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char CMPMON0:1;
        } BIT;
    } CMPMON;
    char           wk3[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char VREFEN:1;
            unsigned char :6;
            unsigned char CPOE:1;
        } BIT;
    } CMPIOC;
};

struct st_cmpc1 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char HCMPON:1;
            unsigned char CDFS:2;
            unsigned char CEG:2;
            unsigned char :1;
            unsigned char COE:1;
            unsigned char CINV:1;
        } BIT;
    } CMPCTL;
    char           wk0[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char CMPSEL:4;
        } BIT;
    } CMPSEL0;
    char           wk1[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char CVRS:2;
        } BIT;
    } CMPSEL1;
    char           wk2[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char CMPMON0:1;
        } BIT;
    } CMPMON;
    char           wk3[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char CPOE:1;
        } BIT;
    } CMPIOC;
};

struct st_cmt {
    union {
        unsigned short WORD;
        struct {
            unsigned short :14;
            unsigned short STR1:1;
            unsigned short STR0:1;
        } BIT;
    } CMSTR0;
    char           wk0[14];
    union {
        unsigned short WORD;
        struct {
            unsigned short :14;
            unsigned short STR3:1;
            unsigned short STR2:1;
        } BIT;
    } CMSTR1;
};

struct st_cmt0 {
    union {
        unsigned short WORD;
        struct {
            unsigned short :9;
            unsigned short CMIE:1;
            unsigned short :4;
            unsigned short CKS:2;
        } BIT;
    } CMCR;
    unsigned short CMCNT;
    unsigned short CMCOR;
};

struct st_crc {
    union {
        unsigned char BYTE;
        struct {
            unsigned char DORCLR:1;
            unsigned char :4;
            unsigned char LMS:1;
            unsigned char GPS:2;
        } BIT;
    } CRCCR;
    unsigned char  CRCDIR;
    unsigned short CRCDOR;
};

struct st_da {
    unsigned short DADR0;
    char           wk0[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char DAOE0:1;
            unsigned char :6;
        } BIT;
    } DACR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char DPSEL:1;
            unsigned char :7;
        } BIT;
    } DADPR;
};

struct st_doc {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char DOPCFCL:1;
            unsigned char DOPCF:1;
            unsigned char DOPCIE:1;
            unsigned char :1;
            unsigned char DCSEL:1;
            unsigned char OMS:2;
        } BIT;
    } DOCR;
    char           wk0[1];
    unsigned short DODIR;
    unsigned short DODSR;
};

struct st_dtc {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char RRS:1;
            unsigned char :4;
        } BIT;
    } DTCCR;
    char           wk0[3];
    void           *DTCVBR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char SHORT:1;
        } BIT;
    } DTCADMOD;
    char           wk1[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char DTCST:1;
        } BIT;
    } DTCST;
    char           wk2[1];
    union {
        unsigned short WORD;
        struct {
            unsigned short ACT:1;
            unsigned short :7;
            unsigned short VECN:8;
        } BIT;
    } DTCSTS;
};

struct st_flash {
    union {
        unsigned char BYTE;
        struct {
            unsigned char FMS2:1;
            unsigned char LVPE:1;
            unsigned char :1;
            unsigned char FMS1:1;
            unsigned char RPDIS:1;
            unsigned char :1;
            unsigned char FMS0:1;
            unsigned char :1;
        } BIT;
    } FPMCR;
    char           wk0[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char EXS:1;
        } BIT;
    } FASR;
    char           wk1[3];
    unsigned short FSARL;
    char           wk2[6];
    unsigned short FSARH;
    char           wk3[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char OPST:1;
            unsigned char STOP:1;
            unsigned char :2;
            unsigned char CMD:4;
        } BIT;
    } FCR;
    char           wk4[3];
    unsigned short FEARL;
    char           wk5[6];
    unsigned short FEARH;
    char           wk6[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char FRESET:1;
        } BIT;
    } FRESETR;
    char           wk7[7];
    union {
        unsigned char BYTE;
        struct {
            unsigned char EXRDY:1;
            unsigned char FRDY:1;
            unsigned char :6;
        } BIT;
    } FSTATR1;
    char           wk8[3];
    unsigned short FWB0;
    char           wk9[6];
    unsigned short FWB1;
    char           wk10[6];
    unsigned short FWB2;
    char           wk11[2];
    unsigned short FWB3;
    char           wk12[58];
    unsigned char  FPR;
    char           wk13[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char PERR:1;
        } BIT;
    } FPSR;
    char           wk14[59];
    union {
        unsigned short WORD;
        struct {
            unsigned short :7;
            unsigned short SASMF:1;
            unsigned short :8;
        } BIT;
    } FSCMR;
    char           wk15[6];
    unsigned short FAWSMR;
    char           wk16[6];
    unsigned short FAWEMR;
    char           wk17[6];
    union {
        unsigned char BYTE;
        struct {
            unsigned char SAS:2;
            unsigned char :1;
            unsigned char PCKA:5;
        } BIT;
    } FISR;
    char           wk18[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char OPST:1;
            unsigned char :4;
            unsigned char CMD:3;
        } BIT;
    } FEXCR;
    char           wk19[3];
    unsigned short FEAML;
    char           wk20[6];
    unsigned short FEAMH;
    char           wk21[6];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char EILGLERR:1;
            unsigned char ILGLERR:1;
            unsigned char BCERR:1;
            unsigned char :1;
            unsigned char PRGERR:1;
            unsigned char ERERR:1;
        } BIT;
    } FSTATR0;
    char           wk22[15809];
    union {
        unsigned short WORD;
        struct {
            unsigned short FEKEY:8;
            unsigned short :7;
            unsigned short FENTRY0:1;
        } BIT;
    } FENTRYR;
};

struct st_flashconst {
    unsigned long  UIDR0;
    unsigned long  UIDR1;
    unsigned long  UIDR2;
    unsigned long  UIDR3;
};

struct st_icu {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char IR:1;
        } BIT;
    } IR[254];
    char           wk0[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char DTCE:1;
        } BIT;
    } DTCER[253];
    char           wk1[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char IEN7:1;
            unsigned char IEN6:1;
            unsigned char IEN5:1;
            unsigned char IEN4:1;
            unsigned char IEN3:1;
            unsigned char IEN2:1;
            unsigned char IEN1:1;
            unsigned char IEN0:1;
        } BIT;
    } IER[32];
    char           wk2[192];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char SWINT:1;
        } BIT;
    } SWINTR;
    char           wk3[15];
    union {
        unsigned short WORD;
        struct {
            unsigned short FIEN:1;
            unsigned short :7;
            unsigned short FVCT:8;
        } BIT;
    } FIR;
    char           wk4[14];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char IPR:4;
        } BIT;
    } IPR[251];
    char           wk5[261];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char IRQMD:2;
            unsigned char :2;
        } BIT;
    } IRQCR[6];
    char           wk6[10];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char FLTEN5:1;
            unsigned char FLTEN4:1;
            unsigned char FLTEN3:1;
            unsigned char FLTEN2:1;
            unsigned char FLTEN1:1;
            unsigned char FLTEN0:1;
        } BIT;
    } IRQFLTE0;
    char           wk7[3];
    union {
        unsigned short WORD;
        struct {
            unsigned short :4;
            unsigned short FCLKSEL5:2;
            unsigned short FCLKSEL4:2;
            unsigned short FCLKSEL3:2;
            unsigned short FCLKSEL2:2;
            unsigned short FCLKSEL1:2;
            unsigned short FCLKSEL0:2;
        } BIT;
    } IRQFLTC0;
    char           wk8[106];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char LVD2ST:1;
            unsigned char LVD1ST:1;
            unsigned char IWDTST:1;
            unsigned char :1;
            unsigned char OSTST:1;
            unsigned char NMIST:1;
        } BIT;
    } NMISR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char LVD2EN:1;
            unsigned char LVD1EN:1;
            unsigned char IWDTEN:1;
            unsigned char :1;
            unsigned char OSTEN:1;
            unsigned char NMIEN:1;
        } BIT;
    } NMIER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char LVD2CLR:1;
            unsigned char LVD1CLR:1;
            unsigned char IWDTCLR:1;
            unsigned char :1;
            unsigned char OSTCLR:1;
            unsigned char NMICLR:1;
        } BIT;
    } NMICLR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char NMIMD:1;
            unsigned char :3;
        } BIT;
    } NMICR;
    char           wk9[12];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char NFLTEN:1;
        } BIT;
    } NMIFLTE;
    char           wk10[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char NFCLKSEL:2;
        } BIT;
    } NMIFLTC;
};

struct st_iwdt {
    unsigned char  IWDTRR;
    char           wk0[1];
    union {
        unsigned short WORD;
        struct {
            unsigned short :2;
            unsigned short RPSS:2;
            unsigned short :2;
            unsigned short RPES:2;
            unsigned short CKS:4;
            unsigned short :2;
            unsigned short TOPS:2;
        } BIT;
    } IWDTCR;
    union {
        unsigned short WORD;
        struct {
            unsigned short REFEF:1;
            unsigned short UNDFF:1;
            unsigned short CNTVAL:14;
        } BIT;
    } IWDTSR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char RSTIRQS:1;
            unsigned char :7;
        } BIT;
    } IWDTRCR;
    char           wk1[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char SLCSTP:1;
            unsigned char :7;
        } BIT;
    } IWDTCSTPR;
};

struct st_mpc {
    union {
        unsigned char BYTE;
        struct {
            unsigned char B0WI:1;
            unsigned char PFSWE:1;
            unsigned char :6;
        } BIT;
    } PWPR;
    char           wk0[32];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :6;
        } BIT;
    } P00PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P01PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P02PFS;
    char           wk1[5];
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P10PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P11PFS;
    char           wk2[8];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P22PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P23PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P24PFS;
    char           wk3[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P30PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P31PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P32PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P33PFS;
    char           wk4[4];
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P40PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P41PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P42PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P43PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P44PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P45PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P46PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char ASEL:1;
            unsigned char :7;
        } BIT;
    } P47PFS;
    char           wk5[16];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P70PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P71PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P72PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P73PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P74PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P75PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P76PFS;
    char           wk6[10];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P91PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } P92PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P93PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } P94PFS;
    char           wk7[5];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PA2PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PA3PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PA4PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PA5PFS;
    char           wk8[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PB0PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PB1PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PB2PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PB3PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PB4PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PB5PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PB6PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PB7PFS;
    char           wk9[11];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PD3PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PD4PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PD5PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char ISEL:1;
            unsigned char :1;
            unsigned char PSEL:5;
        } BIT;
    } PD6PFS;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PD7PFS;
    char           wk10[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PSEL:5;
        } BIT;
    } PE2PFS;
};

struct st_mpu {
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE0;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE0;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE1;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE1;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE2;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE2;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE3;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE3;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE4;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE4;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE5;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE5;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE6;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE6;
    union {
        unsigned long LONG;
        struct {
            unsigned long RSPN:28;
            unsigned long :4;
        } BIT;
    } RSPAGE7;
    union {
        unsigned long LONG;
        struct {
            unsigned long REPN:28;
            unsigned long UAC:3;
            unsigned long V:1;
        } BIT;
    } REPAGE7;
    char           wk0[192];
    union {
        unsigned long LONG;
        struct {
            unsigned long :31;
            unsigned long MPEN:1;
        } BIT;
    } MPEN;
    union {
        unsigned long LONG;
        struct {
            unsigned long :28;
            unsigned long UBAC:3;
            unsigned long :1;
        } BIT;
    } MPBAC;
    union {
        unsigned long LONG;
        struct {
            unsigned long :31;
            unsigned long CLR:1;
        } BIT;
    } MPECLR;
    union {
        unsigned long LONG;
        struct {
            unsigned long :29;
            unsigned long DRW:1;
            unsigned long DMPER:1;
            unsigned long IMPER:1;
        } BIT;
    } MPESTS;
    char           wk1[4];
    union {
        unsigned long LONG;
        struct {
            unsigned long DEA:32;
        } BIT;
    } MPDEA;
    char           wk2[8];
    union {
        unsigned long LONG;
        struct {
            unsigned long SA:32;
        } BIT;
    } MPSA;
    union {
        unsigned short WORD;
        struct {
            unsigned short :15;
            unsigned short S:1;
        } BIT;
    } MPOPS;
    union {
        unsigned short WORD;
        struct {
            unsigned short :15;
            unsigned short INV:1;
        } BIT;
    } MPOPI;
    union {
        unsigned long LONG;
        struct {
            unsigned long :8;
            unsigned long HITI:8;
            unsigned long :12;
            unsigned long UHACI:3;
            unsigned long :1;
        } BIT;
    } MHITI;
    union {
        unsigned long LONG;
        struct {
            unsigned long :8;
            unsigned long HITD:8;
            unsigned long :12;
            unsigned long UHACD:3;
            unsigned long :1;
        } BIT;
    } MHITD;
};

struct st_mtu {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char OE4D:1;
            unsigned char OE4C:1;
            unsigned char OE3D:1;
            unsigned char OE4B:1;
            unsigned char OE4A:1;
            unsigned char OE3B:1;
        } BIT;
    } TOERA;
    char           wk0[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char BDC:1;
            unsigned char N:1;
            unsigned char P:1;
            unsigned char FB:1;
            unsigned char WF:1;
            unsigned char VF:1;
            unsigned char UF:1;
        } BIT;
    } TGCRA;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char PSYE:1;
            unsigned char :2;
            unsigned char TOCL:1;
            unsigned char TOCS:1;
            unsigned char OLSN:1;
            unsigned char OLSP:1;
        } BIT;
    } TOCR1A;
    union {
        unsigned char BYTE;
        struct {
            unsigned char BF:2;
            unsigned char OLS3N:1;
            unsigned char OLS3P:1;
            unsigned char OLS2N:1;
            unsigned char OLS2P:1;
            unsigned char OLS1N:1;
            unsigned char OLS1P:1;
        } BIT;
    } TOCR2A;
    char           wk1[4];
    unsigned short TCDRA;
    unsigned short TDDRA;
    char           wk2[8];
    unsigned short TCNTSA;
    unsigned short TCBRA;
    char           wk3[12];
    union {
        unsigned char BYTE;
        struct {
            unsigned char T3AEN:1;
            unsigned char T3ACOR:3;
            unsigned char T4VEN:1;
            unsigned char T4VCOR:3;
        } BIT;
    } TITCR1A;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char T3ACNT:3;
            unsigned char :1;
            unsigned char T4VCNT:3;
        } BIT;
    } TITCNT1A;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char BTE:2;
        } BIT;
    } TBTERA;
    char           wk4[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char TDER:1;
        } BIT;
    } TDERA;
    char           wk5[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char OLS3N:1;
            unsigned char OLS3P:1;
            unsigned char OLS2N:1;
            unsigned char OLS2P:1;
            unsigned char OLS1N:1;
            unsigned char OLS1P:1;
        } BIT;
    } TOLBRA;
    char           wk6[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char TITM:1;
        } BIT;
    } TITMRA;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TRG4COR:3;
        } BIT;
    } TITCR2A;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TRG4CNT:3;
        } BIT;
    } TITCNT2A;
    char           wk7[35];
    union {
        unsigned char BYTE;
        struct {
            unsigned char CCE:1;
            unsigned char :6;
            unsigned char WRE:1;
        } BIT;
    } TWCRA;
    char           wk8[15];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char DRS:1;
        } BIT;
    } TMDR2A;
    char           wk9[15];
    union {
        unsigned char BYTE;
        struct {
            unsigned char CST4:1;
            unsigned char CST3:1;
            unsigned char :3;
            unsigned char CST2:1;
            unsigned char CST1:1;
            unsigned char CST0:1;
        } BIT;
    } TSTRA;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SYNC4:1;
            unsigned char SYNC3:1;
            unsigned char :3;
            unsigned char SYNC2:1;
            unsigned char SYNC1:1;
            unsigned char SYNC0:1;
        } BIT;
    } TSYRA;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SCH0:1;
            unsigned char SCH1:1;
            unsigned char SCH2:1;
            unsigned char SCH3:1;
            unsigned char SCH4:1;
            unsigned char :3;
        } BIT;
    } TCSYSTR;
    char           wk10[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char RWE:1;
        } BIT;
    } TRWERA;
    char           wk11[2731];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char TADSTRS0:5;
        } BIT;
    } TADSTRGR0;
};

struct st_mtu0 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char NFDEN:1;
            unsigned char NFCEN:1;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCR0;
    char           wk0[8];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char NFDEN:1;
            unsigned char NFCEN:1;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCRC;
    char           wk1[102];
    union {
        unsigned char BYTE;
        struct {
            unsigned char CCLR:3;
            unsigned char CKEG:2;
            unsigned char TPSC:3;
        } BIT;
    } TCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char BFE:1;
            unsigned char BFB:1;
            unsigned char BFA:1;
            unsigned char MD:4;
        } BIT;
    } TMDR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOB:4;
            unsigned char IOA:4;
        } BIT;
    } TIORH;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOD:4;
            unsigned char IOC:4;
        } BIT;
    } TIORL;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE:1;
            unsigned char :2;
            unsigned char TCIEV:1;
            unsigned char TGIED:1;
            unsigned char TGIEC:1;
            unsigned char TGIEB:1;
            unsigned char TGIEA:1;
        } BIT;
    } TIER;
    char           wk2[1];
    unsigned short TCNT;
    unsigned short TGRA;
    unsigned short TGRB;
    unsigned short TGRC;
    unsigned short TGRD;
    char           wk3[16];
    unsigned short TGRE;
    unsigned short TGRF;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE2:1;
            unsigned char :5;
            unsigned char TGIEF:1;
            unsigned char TGIEE:1;
        } BIT;
    } TIER2;
    char           wk4[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TTSE:1;
            unsigned char TTSB:1;
            unsigned char TTSA:1;
        } BIT;
    } TBTM;
    char           wk5[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2;
};

struct st_mtu1 {
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char :2;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCR1;
    char           wk1[238];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char CCLR:2;
            unsigned char CKEG:2;
            unsigned char TPSC:3;
        } BIT;
    } TCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char MD:4;
        } BIT;
    } TMDR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOB:4;
            unsigned char IOA:4;
        } BIT;
    } TIOR;
    char           wk2[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE:1;
            unsigned char :1;
            unsigned char TCIEU:1;
            unsigned char TCIEV:1;
            unsigned char :2;
            unsigned char TGIEB:1;
            unsigned char TGIEA:1;
        } BIT;
    } TIER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TCFD:1;
            unsigned char :7;
        } BIT;
    } TSR;
    unsigned short TCNT;
    unsigned short TGRA;
    unsigned short TGRB;
    char           wk3[4];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char I2BE:1;
            unsigned char I2AE:1;
            unsigned char I1BE:1;
            unsigned char I1AE:1;
        } BIT;
    } TICCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char PHCKSEL:1;
            unsigned char LWA:1;
        } BIT;
    } TMDR3;
    char           wk4[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PCB:2;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2;
    char           wk5[11];
    unsigned long  TCNTLW;
    unsigned long  TGRALW;
    unsigned long  TGRBLW;
};

struct st_mtu2 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char :2;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCR2;
    char           wk0[365];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char CCLR:2;
            unsigned char CKEG:2;
            unsigned char TPSC:3;
        } BIT;
    } TCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char MD:4;
        } BIT;
    } TMDR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOB:4;
            unsigned char IOA:4;
        } BIT;
    } TIOR;
    char           wk1[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE:1;
            unsigned char :1;
            unsigned char TCIEU:1;
            unsigned char TCIEV:1;
            unsigned char :2;
            unsigned char TGIEB:1;
            unsigned char TGIEA:1;
        } BIT;
    } TIER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TCFD:1;
            unsigned char :7;
        } BIT;
    } TSR;
    unsigned short TCNT;
    unsigned short TGRA;
    unsigned short TGRB;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char PCB:2;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2;
};

struct st_mtu3 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char CCLR:3;
            unsigned char CKEG:2;
            unsigned char TPSC:3;
        } BIT;
    } TCR;
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char BFB:1;
            unsigned char BFA:1;
            unsigned char MD:4;
        } BIT;
    } TMDR1;
    char           wk1[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOB:4;
            unsigned char IOA:4;
        } BIT;
    } TIORH;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOD:4;
            unsigned char IOC:4;
        } BIT;
    } TIORL;
    char           wk2[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE:1;
            unsigned char :2;
            unsigned char TCIEV:1;
            unsigned char TGIED:1;
            unsigned char TGIEC:1;
            unsigned char TGIEB:1;
            unsigned char TGIEA:1;
        } BIT;
    } TIER;
    char           wk3[7];
    unsigned short TCNT;
    char           wk4[6];
    unsigned short TGRA;
    unsigned short TGRB;
    char           wk5[8];
    unsigned short TGRC;
    unsigned short TGRD;
    char           wk6[4];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TCFD:1;
            unsigned char :7;
        } BIT;
    } TSR;
    char           wk7[11];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TTSB:1;
            unsigned char TTSA:1;
        } BIT;
    } TBTM;
    char           wk8[19];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2;
    char           wk9[37];
    unsigned short TGRE;
    char           wk10[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char NFDEN:1;
            unsigned char NFCEN:1;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCR3;
};

struct st_mtu4 {
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char CCLR:3;
            unsigned char CKEG:2;
            unsigned char TPSC:3;
        } BIT;
    } TCR;
    char           wk1[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char BFB:1;
            unsigned char BFA:1;
            unsigned char MD:4;
        } BIT;
    } TMDR1;
    char           wk2[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOB:4;
            unsigned char IOA:4;
        } BIT;
    } TIORH;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IOD:4;
            unsigned char IOC:4;
        } BIT;
    } TIORL;
    char           wk3[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TTGE:1;
            unsigned char TTGE2:1;
            unsigned char :1;
            unsigned char TCIEV:1;
            unsigned char TGIED:1;
            unsigned char TGIEC:1;
            unsigned char TGIEB:1;
            unsigned char TGIEA:1;
        } BIT;
    } TIER;
    char           wk4[8];
    unsigned short TCNT;
    char           wk5[8];
    unsigned short TGRA;
    unsigned short TGRB;
    char           wk6[8];
    unsigned short TGRC;
    unsigned short TGRD;
    char           wk7[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TCFD:1;
            unsigned char :7;
        } BIT;
    } TSR;
    char           wk8[11];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TTSB:1;
            unsigned char TTSA:1;
        } BIT;
    } TBTM;
    char           wk9[6];
    union {
        unsigned short WORD;
        struct {
            unsigned short BF:2;
            unsigned short :6;
            unsigned short UT4AE:1;
            unsigned short DT4AE:1;
            unsigned short UT4BE:1;
            unsigned short DT4BE:1;
            unsigned short ITA3AE:1;
            unsigned short ITA4VE:1;
            unsigned short ITB3AE:1;
            unsigned short ITB4VE:1;
        } BIT;
    } TADCR;
    char           wk10[2];
    unsigned short TADCORA;
    unsigned short TADCORB;
    unsigned short TADCOBRA;
    unsigned short TADCOBRB;
    char           wk11[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2;
    char           wk12[38];
    unsigned short TGRE;
    unsigned short TGRF;
    char           wk13[28];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char NFDEN:1;
            unsigned char NFCEN:1;
            unsigned char NFBEN:1;
            unsigned char NFAEN:1;
        } BIT;
    } NFCR4;
};

struct st_mtu5 {
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char NFCS:2;
            unsigned char :1;
            unsigned char NFWEN:1;
            unsigned char NFVEN:1;
            unsigned char NFUEN:1;
        } BIT;
    } NFCR5;
    char           wk1[490];
    unsigned short TCNTU;
    unsigned short TGRU;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TPSC:2;
        } BIT;
    } TCRU;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char CKEG:2;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2U;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char IOC:5;
        } BIT;
    } TIORU;
    char           wk2[9];
    unsigned short TCNTV;
    unsigned short TGRV;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TPSC:2;
        } BIT;
    } TCRV;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char CKEG:2;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2V;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char IOC:5;
        } BIT;
    } TIORV;
    char           wk3[9];
    unsigned short TCNTW;
    unsigned short TGRW;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char TPSC:2;
        } BIT;
    } TCRW;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char CKEG:2;
            unsigned char TPSC2:3;
        } BIT;
    } TCR2W;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char IOC:5;
        } BIT;
    } TIORW;
    char           wk4[11];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char TGIE5U:1;
            unsigned char TGIE5V:1;
            unsigned char TGIE5W:1;
        } BIT;
    } TIER;
    char           wk5[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char CSTU5:1;
            unsigned char CSTV5:1;
            unsigned char CSTW5:1;
        } BIT;
    } TSTR;
    char           wk6[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char CMPCLR5U:1;
            unsigned char CMPCLR5V:1;
            unsigned char CMPCLR5W:1;
        } BIT;
    } TCNTCMPCLR;
};

struct st_poe {
    union {
        unsigned short WORD;
        struct {
            unsigned char H;
            unsigned char L;
        } BYTE;
        struct {
            unsigned char :3;
            unsigned char POE0F:1;
            unsigned char :3;
            unsigned char PIE1:1;
            unsigned char :6;
            unsigned char POE0M:2;
        } BIT;
    } ICSR1;
    union {
        unsigned short WORD;
        struct {
            unsigned char H;
            unsigned char L;
        } BYTE;
        struct {
            unsigned char OSF1:1;
            unsigned char :5;
            unsigned char OCE1:1;
            unsigned char OIE1:1;
            unsigned char :8;
        } BIT;
    } OCSR1;
    char           wk0[4];
    union {
        unsigned short WORD;
        struct {
            unsigned char H;
            unsigned char L;
        } BYTE;
        struct {
            unsigned char :3;
            unsigned char POE8F:1;
            unsigned char :2;
            unsigned char POE8E:1;
            unsigned char PIE3:1;
            unsigned char :6;
            unsigned char POE8M:2;
        } BIT;
    } ICSR3;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char MTUCH0HIZ:1;
            unsigned char :1;
            unsigned char MTUCH34HIZ:1;
        } BIT;
    } SPOER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char MTU0C1ZE:1;
            unsigned char MTU0B2ZE:1;
            unsigned char MTU0B1ZE:1;
            unsigned char MTU0A1ZE:1;
            unsigned char MTU0DZE:1;
            unsigned char MTU0CZE:1;
            unsigned char MTU0BZE:1;
            unsigned char MTU0AZE:1;
        } BIT;
    } POECR1;
    union {
        unsigned short WORD;
        struct {
            unsigned short :5;
            unsigned short MTU3BDZE:1;
            unsigned short MTU4ACZE:1;
            unsigned short MTU4BDZE:1;
            unsigned short :8;
        } BIT;
    } POECR2;
    char           wk1[2];
    union {
        unsigned short WORD;
        struct {
            unsigned short :11;
            unsigned short IC4ADDMT34ZE:1;
            unsigned short IC3ADDMT34ZE:1;
            unsigned short :2;
            unsigned short CMADDMT34ZE:1;
        } BIT;
    } POECR4;
    union {
        unsigned short WORD;
        struct {
            unsigned short :11;
            unsigned short IC4ADDMT0ZE:1;
            unsigned short :2;
            unsigned short IC1ADDMT0ZE:1;
            unsigned short CMADDMT0ZE:1;
        } BIT;
    } POECR5;
    char           wk2[2];
    union {
        unsigned short WORD;
        struct {
            unsigned char H;
            unsigned char L;
        } BYTE;
        struct {
            unsigned char :3;
            unsigned char POE10F:1;
            unsigned char :2;
            unsigned char POE10E:1;
            unsigned char PIE4:1;
            unsigned char :6;
            unsigned char POE10M:2;
        } BIT;
    } ICSR4;
    char           wk3[2];
    union {
        unsigned short WORD;
        struct {
            unsigned char H;
            unsigned char L;
        } BYTE;
        struct {
            unsigned char :8;
            unsigned char OLSEN:1;
            unsigned char :1;
            unsigned char OLSG2B:1;
            unsigned char OLSG2A:1;
            unsigned char OLSG1B:1;
            unsigned char OLSG1A:1;
            unsigned char OLSG0B:1;
            unsigned char OLSG0A:1;
        } BIT;
    } ALR1;
    union {
        unsigned short WORD;
        struct {
            unsigned short :3;
            unsigned short OSTSTF:1;
            unsigned short :2;
            unsigned short OSTSTE:1;
            unsigned short :9;
        } BIT;
    } ICSR6;
    char           wk4[8];
    union {
        unsigned short WORD;
        struct {
            unsigned short :13;
            unsigned short C2FLAG:1;
            unsigned short C1FLAG:1;
            unsigned short C0FLAG:1;
        } BIT;
    } POECMPFR;
    union {
        unsigned short WORD;
        struct {
            unsigned short :13;
            unsigned short POEREQ2:1;
            unsigned short POEREQ1:1;
            unsigned short POEREQ0:1;
        } BIT;
    } POECMPSEL;
};

struct st_port0 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PMR;
    char           wk3[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR0;
    char           wk4[63];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } DSCR;
};

struct st_port1 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PMR;
    char           wk3[32];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR0;
    char           wk4[62];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } DSCR;
};

struct st_port2 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PMR;
    char           wk3[33];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :4;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[60];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } DSCR;
};

struct st_port3 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PMR;
    char           wk3[34];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :4;
        } BIT;
    } ODR1;
    char           wk4[59];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :2;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } DSCR;
};

struct st_port4 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[127];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
};

struct st_port7 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PMR;
    char           wk3[38];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[55];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char B0:1;
        } BIT;
    } DSCR;
};

struct st_port9 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } PMR;
    char           wk3[40];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[53];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char :1;
        } BIT;
    } DSCR;
};

struct st_porta {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PMR;
    char           wk3[41];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :4;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[52];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } DSCR;
};

struct st_portb {
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PMR;
    char           wk3[42];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[51];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char B2:1;
            unsigned char B1:1;
            unsigned char B0:1;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :2;
            unsigned char B0:1;
        } BIT;
    } DSCR;
};

struct st_portd {
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :3;
        } BIT;
    } PDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :3;
        } BIT;
    } PODR;
    char           wk1[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :3;
        } BIT;
    } PIDR;
    char           wk2[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :3;
        } BIT;
    } PMR;
    char           wk3[44];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :6;
        } BIT;
    } ODR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char B6:1;
            unsigned char :1;
            unsigned char B4:1;
            unsigned char :1;
            unsigned char B2:1;
            unsigned char :1;
            unsigned char B0:1;
        } BIT;
    } ODR1;
    char           wk4[49];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char B3:1;
            unsigned char :3;
        } BIT;
    } PCR;
    char           wk5[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char B7:1;
            unsigned char B6:1;
            unsigned char B5:1;
            unsigned char B4:1;
            unsigned char :4;
        } BIT;
    } DSCR;
};

struct st_porte {
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PIDR;
    char           wk0[31];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char B2:1;
            unsigned char :2;
        } BIT;
    } PMR;
};

struct st_riic {
    union {
        unsigned char BYTE;
        struct {
            unsigned char ICE:1;
            unsigned char IICRST:1;
            unsigned char CLO:1;
            unsigned char SOWP:1;
            unsigned char SCLO:1;
            unsigned char SDAO:1;
            unsigned char SCLI:1;
            unsigned char SDAI:1;
        } BIT;
    } ICCR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char BBSY:1;
            unsigned char MST:1;
            unsigned char TRS:1;
            unsigned char :1;
            unsigned char SP:1;
            unsigned char RS:1;
            unsigned char ST:1;
            unsigned char :1;
        } BIT;
    } ICCR2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char MTWP:1;
            unsigned char CKS:3;
            unsigned char BCWP:1;
            unsigned char BC:3;
        } BIT;
    } ICMR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char DLCS:1;
            unsigned char SDDL:3;
            unsigned char :1;
            unsigned char TMOH:1;
            unsigned char TMOL:1;
            unsigned char TMOS:1;
        } BIT;
    } ICMR2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SMBS:1;
            unsigned char WAIT:1;
            unsigned char RDRFS:1;
            unsigned char ACKWP:1;
            unsigned char ACKBT:1;
            unsigned char ACKBR:1;
            unsigned char NF:2;
        } BIT;
    } ICMR3;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char SCLE:1;
            unsigned char NFE:1;
            unsigned char NACKE:1;
            unsigned char SALE:1;
            unsigned char NALE:1;
            unsigned char MALE:1;
            unsigned char TMOE:1;
        } BIT;
    } ICFER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char HOAE:1;
            unsigned char :1;
            unsigned char DIDE:1;
            unsigned char :1;
            unsigned char GCAE:1;
            unsigned char SAR2E:1;
            unsigned char SAR1E:1;
            unsigned char SAR0E:1;
        } BIT;
    } ICSER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TIE:1;
            unsigned char TEIE:1;
            unsigned char RIE:1;
            unsigned char NAKIE:1;
            unsigned char SPIE:1;
            unsigned char STIE:1;
            unsigned char ALIE:1;
            unsigned char TMOIE:1;
        } BIT;
    } ICIER;
    union {
        unsigned char BYTE;
        struct {
            unsigned char HOA:1;
            unsigned char :1;
            unsigned char DID:1;
            unsigned char :1;
            unsigned char GCA:1;
            unsigned char AAS2:1;
            unsigned char AAS1:1;
            unsigned char AAS0:1;
        } BIT;
    } ICSR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TDRE:1;
            unsigned char TEND:1;
            unsigned char RDRF:1;
            unsigned char NACKF:1;
            unsigned char STOP:1;
            unsigned char START:1;
            unsigned char AL:1;
            unsigned char TMOF:1;
        } BIT;
    } ICSR2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SVA:7;
            unsigned char SVA0:1;
        } BIT;
    } SARL0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SVA:2;
            unsigned char FS:1;
        } BIT;
    } SARU0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SVA:7;
            unsigned char SVA0:1;
        } BIT;
    } SARL1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SVA:2;
            unsigned char FS:1;
        } BIT;
    } SARU1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SVA:7;
            unsigned char SVA0:1;
        } BIT;
    } SARL2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SVA:2;
            unsigned char FS:1;
        } BIT;
    } SARU2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char BRL:5;
        } BIT;
    } ICBRL;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char BRH:5;
        } BIT;
    } ICBRH;
    unsigned char  ICDRT;
    unsigned char  ICDRR;
};

struct st_rspi {
    union {
        unsigned char BYTE;
        struct {
            unsigned char SPRIE:1;
            unsigned char SPE:1;
            unsigned char SPTIE:1;
            unsigned char SPEIE:1;
            unsigned char MSTR:1;
            unsigned char MODFEN:1;
            unsigned char TXMD:1;
            unsigned char SPMS:1;
        } BIT;
    } SPCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char SSL3P:1;
            unsigned char SSL2P:1;
            unsigned char SSL1P:1;
            unsigned char SSL0P:1;
        } BIT;
    } SSLP;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char MOIFE:1;
            unsigned char MOIFV:1;
            unsigned char :2;
            unsigned char SPLP2:1;
            unsigned char SPLP:1;
        } BIT;
    } SPPCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char SPRF:1;
            unsigned char :1;
            unsigned char SPTEF:1;
            unsigned char :1;
            unsigned char PERF:1;
            unsigned char MODF:1;
            unsigned char IDLNF:1;
            unsigned char OVRF:1;
        } BIT;
    } SPSR;
    union {
        unsigned long LONG;
        struct {
            unsigned short H;
        } WORD;
    } SPDR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SPSLN:3;
        } BIT;
    } SPSCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char SPECM:3;
            unsigned char :1;
            unsigned char SPCP:3;
        } BIT;
    } SPSSR;
    unsigned char  SPBR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char SPLW:1;
            unsigned char SPRDTD:1;
            unsigned char :2;
            unsigned char SPFC:2;
        } BIT;
    } SPDCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SCKDL:3;
        } BIT;
    } SPCKD;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SLNDL:3;
        } BIT;
    } SSLND;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SPNDL:3;
        } BIT;
    } SPND;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char SCKASE:1;
            unsigned char PTE:1;
            unsigned char SPIIE:1;
            unsigned char SPOE:1;
            unsigned char SPPE:1;
        } BIT;
    } SPCR2;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD0;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD1;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD2;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD3;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD4;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD5;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD6;
    union {
        unsigned short WORD;
        struct {
            unsigned short SCKDEN:1;
            unsigned short SLNDEN:1;
            unsigned short SPNDEN:1;
            unsigned short LSBF:1;
            unsigned short SPB:4;
            unsigned short SSLKP:1;
            unsigned short SSLA:3;
            unsigned short BRDV:2;
            unsigned short CPOL:1;
            unsigned short CPHA:1;
        } BIT;
    } SPCMD7;
};

struct st_s12ad {
    union {
        unsigned short WORD;
        struct {
            unsigned short ADST:1;
            unsigned short ADCS:2;
            unsigned short ADIE:1;
            unsigned short :2;
            unsigned short TRGE:1;
            unsigned short EXTRG:1;
            unsigned short DBLE:1;
            unsigned short GBADIE:1;
            unsigned short :1;
            unsigned short DBLANS:5;
        } BIT;
    } ADCSR;
    char           wk0[2];
    union {
        unsigned short WORD;
        struct {
            unsigned short :8;
            unsigned short ANSA007:1;
            unsigned short ANSA006:1;
            unsigned short ANSA005:1;
            unsigned short ANSA004:1;
            unsigned short ANSA003:1;
            unsigned short ANSA002:1;
            unsigned short ANSA001:1;
            unsigned short ANSA000:1;
        } BIT;
    } ADANSA0;
    union {
        unsigned short WORD;
        struct {
            unsigned short :14;
            unsigned short ANSA101:1;
            unsigned short ANSA100:1;
        } BIT;
    } ADANSA1;
    union {
        unsigned short WORD;
        struct {
            unsigned short :8;
            unsigned short ADS007:1;
            unsigned short ADS006:1;
            unsigned short ADS005:1;
            unsigned short ADS004:1;
            unsigned short ADS003:1;
            unsigned short ADS002:1;
            unsigned short ADS001:1;
            unsigned short ADS000:1;
        } BIT;
    } ADADS0;
    union {
        unsigned short WORD;
        struct {
            unsigned short :14;
            unsigned short ADS101:1;
            unsigned short ADS100:1;
        } BIT;
    } ADADS1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char AVEE:1;
            unsigned char :4;
            unsigned char ADC:3;
        } BIT;
    } ADADC;
    char           wk1[1];
    union {
        unsigned short WORD;
        struct {
            unsigned short ADRFMT:1;
            unsigned short :3;
            unsigned short DIAGM:1;
            unsigned short DIAGLD:1;
            unsigned short DIAGVAL:2;
            unsigned short :2;
            unsigned short ACE:1;
            unsigned short :5;
        } BIT;
    } ADCER;
    union {
        unsigned short WORD;
        struct {
            unsigned short :2;
            unsigned short TRSA:6;
            unsigned short :2;
            unsigned short TRSB:6;
        } BIT;
    } ADSTRGR;
    union {
        unsigned short WORD;
        struct {
            unsigned short :6;
            unsigned short OCSA:1;
            unsigned short :7;
            unsigned short OCSAD:1;
            unsigned short :1;
        } BIT;
    } ADEXICR;
    union {
        unsigned short WORD;
        struct {
            unsigned short :8;
            unsigned short ANSB007:1;
            unsigned short ANSB006:1;
            unsigned short ANSB005:1;
            unsigned short ANSB004:1;
            unsigned short ANSB003:1;
            unsigned short ANSB002:1;
            unsigned short ANSB001:1;
            unsigned short ANSB000:1;
        } BIT;
    } ADANSB0;
    union {
        unsigned short WORD;
        struct {
            unsigned short :14;
            unsigned short ANSB101:1;
            unsigned short ANSB100:1;
        } BIT;
    } ADANSB1;
    unsigned short ADDBLDR;
    char           wk2[2];
    unsigned short ADOCDR;
    unsigned short ADRD;
    unsigned short ADDR0;
    unsigned short ADDR1;
    unsigned short ADDR2;
    unsigned short ADDR3;
    unsigned short ADDR4;
    unsigned short ADDR5;
    unsigned short ADDR6;
    unsigned short ADDR7;
    char           wk3[16];
    unsigned short ADDR16;
    unsigned short ADDR17;
    char           wk4[34];
    union {
        unsigned short WORD;
        struct {
            unsigned short :5;
            unsigned short SHANS:3;
            unsigned short SSTSH:8;
        } BIT;
    } ADSHCR;
    char           wk5[18];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char ADNDIS:5;
        } BIT;
    } ADDISCR;
    char           wk6[5];
    union {
        unsigned short WORD;
        struct {
            unsigned short GBRP:1;
            unsigned short :13;
            unsigned short GBRSCN:1;
            unsigned short PGS:1;
        } BIT;
    } ADGSPCR;
    char           wk7[2];
    unsigned short ADDBLDRA;
    unsigned short ADDBLDRB;
    char           wk8[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char LVSEL:1;
            unsigned char :3;
            unsigned char HVSEL:1;
        } BIT;
    } ADHVREFCNT;
    char           wk9[82];
    unsigned char  ADSSTRL;
    char           wk10[1];
    unsigned char  ADSSTRO;
    unsigned char  ADSSTR0;
    unsigned char  ADSSTR1;
    unsigned char  ADSSTR2;
    unsigned char  ADSSTR3;
    unsigned char  ADSSTR4;
    unsigned char  ADSSTR5;
    unsigned char  ADSSTR6;
    unsigned char  ADSSTR7;
};

struct st_sci {
    union {
        unsigned char BYTE;
        struct {
            unsigned char CM:1;
            unsigned char CHR:1;
            unsigned char PE:1;
            unsigned char PM:1;
            unsigned char STOP:1;
            unsigned char MP:1;
            unsigned char CKS:2;
        } BIT;
    } SMR;
    unsigned char  BRR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TIE:1;
            unsigned char RIE:1;
            unsigned char TE:1;
            unsigned char RE:1;
            unsigned char MPIE:1;
            unsigned char TEIE:1;
            unsigned char CKE:2;
        } BIT;
    } SCR;
    unsigned char  TDR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TDRE:1;
            unsigned char RDRF:1;
            unsigned char ORER:1;
            unsigned char FER:1;
            unsigned char PER:1;
            unsigned char TEND:1;
            unsigned char MPB:1;
            unsigned char MPBT:1;
        } BIT;
    } SSR;
    unsigned char  RDR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char BCP2:1;
            unsigned char :2;
            unsigned char CHR1:1;
            unsigned char SDIR:1;
            unsigned char SINV:1;
            unsigned char :1;
            unsigned char SMIF:1;
        } BIT;
    } SCMR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char RXDESEL:1;
            unsigned char BGDM:1;
            unsigned char NFEN:1;
            unsigned char ABCS:1;
            unsigned char :1;
            unsigned char BRME:1;
            unsigned char :1;
            unsigned char ACS0:1;
        } BIT;
    } SEMR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char NFCS:3;
        } BIT;
    } SNFR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IICDL:5;
            unsigned char :2;
            unsigned char IICM:1;
        } BIT;
    } SIMR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char IICACKT:1;
            unsigned char :3;
            unsigned char IICCSC:1;
            unsigned char IICINTM:1;
        } BIT;
    } SIMR2;
    union {
        unsigned char BYTE;
        struct {
            unsigned char IICSCLS:2;
            unsigned char IICSDAS:2;
            unsigned char IICSTIF:1;
            unsigned char IICSTPREQ:1;
            unsigned char IICRSTAREQ:1;
            unsigned char IICSTAREQ:1;
        } BIT;
    } SIMR3;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char IICACKR:1;
        } BIT;
    } SISR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char CKPH:1;
            unsigned char CKPOL:1;
            unsigned char :1;
            unsigned char MFF:1;
            unsigned char :1;
            unsigned char MSS:1;
            unsigned char CTSE:1;
            unsigned char SSE:1;
        } BIT;
    } SPMR;
    union {
        unsigned short WORD;
        struct {
            unsigned char TDRH;
            unsigned char TDRL;
        } BYTE;
    } TDRHL;
    union {
        unsigned short WORD;
        struct {
            unsigned char RDRH;
            unsigned char RDRL;
        } BYTE;
    } RDRHL;
    unsigned char  MDDR;
};

struct st_smci {
    union {
        unsigned char BYTE;
        struct {
            unsigned char GM:1;
            unsigned char BLK:1;
            unsigned char PE:1;
            unsigned char PM:1;
            unsigned char BCP:2;
            unsigned char CKS:2;
        } BIT;
    } SMR;
    unsigned char  BRR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TIE:1;
            unsigned char RIE:1;
            unsigned char TE:1;
            unsigned char RE:1;
            unsigned char MPIE:1;
            unsigned char TEIE:1;
            unsigned char CKE:2;
        } BIT;
    } SCR;
    unsigned char  TDR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char TDRE:1;
            unsigned char RDRF:1;
            unsigned char ORER:1;
            unsigned char ERS:1;
            unsigned char PER:1;
            unsigned char TEND:1;
            unsigned char MPB:1;
            unsigned char MPBT:1;
        } BIT;
    } SSR;
    unsigned char  RDR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char BCP2:1;
            unsigned char :2;
            unsigned char CHR1:1;
            unsigned char SDIR:1;
            unsigned char SINV:1;
            unsigned char :1;
            unsigned char SMIF:1;
        } BIT;
    } SCMR;
    char           wk0[7];
    union {
        unsigned short WORD;
        struct {
            unsigned char TDRH;
            unsigned char TDRL;
        } BYTE;
    } TDRHL;
    union {
        unsigned short WORD;
        struct {
            unsigned char RDRH;
            unsigned char RDRL;
        } BYTE;
    } RDRHL;
    unsigned char  MDDR;
};

struct st_system {
    union {
        unsigned short WORD;
        struct {
            unsigned short :15;
            unsigned short MD:1;
        } BIT;
    } MDMONR;
    char           wk0[6];
    union {
        unsigned short WORD;
        struct {
            unsigned short :15;
            unsigned short RAME:1;
        } BIT;
    } SYSCR1;
    char           wk1[2];
    union {
        unsigned short WORD;
        struct {
            unsigned short SSBY:1;
            unsigned short :15;
        } BIT;
    } SBYCR;
    char           wk2[2];
    union {
        unsigned long LONG;
        struct {
            unsigned long :3;
            unsigned long MSTPA28:1;
            unsigned long :8;
            unsigned long MSTPA19:1;
            unsigned long :1;
            unsigned long MSTPA17:1;
            unsigned long :1;
            unsigned long MSTPA15:1;
            unsigned long MSTPA14:1;
            unsigned long :4;
            unsigned long MSTPA9:1;
            unsigned long :3;
            unsigned long MSTPA5:1;
            unsigned long MSTPA4:1;
            unsigned long :4;
        } BIT;
    } MSTPCRA;
    union {
        unsigned long LONG;
        struct {
            unsigned long :1;
            unsigned long MSTPB30:1;
            unsigned long :3;
            unsigned long MSTPB26:1;
            unsigned long :2;
            unsigned long MSTPB23:1;
            unsigned long :1;
            unsigned long MSTPB21:1;
            unsigned long :3;
            unsigned long MSTPB17:1;
            unsigned long :6;
            unsigned long MSTPB10:1;
            unsigned long :3;
            unsigned long MSTPB6:1;
            unsigned long :6;
        } BIT;
    } MSTPCRB;
    union {
        unsigned long LONG;
        struct {
            unsigned long DSLPE:1;
            unsigned long :11;
            unsigned long MSTPC19:1;
            unsigned long :18;
            unsigned long MSTPC0:1;
        } BIT;
    } MSTPCRC;
    char           wk3[4];
    union {
        unsigned long LONG;
        struct {
            unsigned long FCK:4;
            unsigned long ICK:4;
            unsigned long :8;
            unsigned long PCKA:4;
            unsigned long PCKB:4;
            unsigned long :4;
            unsigned long PCKD:4;
        } BIT;
    } SCKCR;
    char           wk4[2];
    union {
        unsigned short WORD;
        struct {
            unsigned short :5;
            unsigned short CKSEL:3;
            unsigned short :8;
        } BIT;
    } SCKCR3;
    union {
        unsigned short WORD;
        struct {
            unsigned short :2;
            unsigned short STC:6;
            unsigned short :6;
            unsigned short PLIDIV:2;
        } BIT;
    } PLLCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char PLLEN:1;
        } BIT;
    } PLLCR2;
    char           wk5[6];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char MEMWAIT:1;
        } BIT;
    } MEMWAIT;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char MOSTP:1;
        } BIT;
    } MOSCCR;
    char           wk6[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char LCSTP:1;
        } BIT;
    } LOCOCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char ILCSTP:1;
        } BIT;
    } ILOCOCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char HCSTP:1;
        } BIT;
    } HOCOCR;
    char           wk7[5];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char HCOVF:1;
            unsigned char PLOVF:1;
            unsigned char :1;
            unsigned char MOOVF:1;
        } BIT;
    } OSCOVFSR;
    char           wk8[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char OSTDE:1;
            unsigned char :6;
            unsigned char OSTDIE:1;
        } BIT;
    } OSTDCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char OSTDF:1;
        } BIT;
    } OSTDSR;
    char           wk9[94];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char OPCMTSF:1;
            unsigned char :1;
            unsigned char OPCM:3;
        } BIT;
    } OPCCR;
    char           wk10[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char MSTS:5;
        } BIT;
    } MOSCWTCR;
    char           wk11[2];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char HSTS:3;
        } BIT;
    } HOCOWTCR;
    char           wk12[26];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char SWRF:1;
            unsigned char :1;
            unsigned char IWDTRF:1;
        } BIT;
    } RSTSR2;
    char           wk13[1];
    unsigned short SWRR;
    char           wk14[28];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char LVD1IRQSEL:1;
            unsigned char LVD1IDTSEL:2;
        } BIT;
    } LVD1CR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char LVD1MON:1;
            unsigned char LVD1DET:1;
        } BIT;
    } LVD1SR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :5;
            unsigned char LVD2IRQSEL:1;
            unsigned char LVD2IDTSEL:2;
        } BIT;
    } LVD2CR1;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :6;
            unsigned char LVD2MON:1;
            unsigned char LVD2DET:1;
        } BIT;
    } LVD2SR;
    char           wk15[794];
    union {
        unsigned short WORD;
        struct {
            unsigned short PRKEY:8;
            unsigned short :4;
            unsigned short PRC3:1;
            unsigned short PRC2:1;
            unsigned short PRC1:1;
            unsigned short PRC0:1;
        } BIT;
    } PRCR;
    char           wk16[48784];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char LVD2RF:1;
            unsigned char LVD1RF:1;
            unsigned char LVD0RF:1;
            unsigned char PORF:1;
        } BIT;
    } RSTSR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :7;
            unsigned char CWSF:1;
        } BIT;
    } RSTSR1;
    char           wk17[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char MOSEL:1;
            unsigned char MODRV21:1;
            unsigned char :5;
        } BIT;
    } MOFCR;
    char           wk18[3];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :1;
            unsigned char LVD2E:1;
            unsigned char LVD1E:1;
            unsigned char :5;
        } BIT;
    } LVCMPCR;
    union {
        unsigned char BYTE;
        struct {
            unsigned char :2;
            unsigned char LVD2LVL:2;
            unsigned char LVD1LVL:4;
        } BIT;
    } LVDLVLR;
    char           wk19[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char LVD1RN:1;
            unsigned char LVD1RI:1;
            unsigned char :3;
            unsigned char LVD1CMPE:1;
            unsigned char :1;
            unsigned char LVD1RIE:1;
        } BIT;
    } LVD1CR0;
    union {
        unsigned char BYTE;
        struct {
            unsigned char LVD2RN:1;
            unsigned char LVD2RI:1;
            unsigned char :3;
            unsigned char LVD2CMPE:1;
            unsigned char :1;
            unsigned char LVD2RIE:1;
        } BIT;
    } LVD2CR0;
};

struct st_tmr0 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char CMIEB:1;
            unsigned char CMIEA:1;
            unsigned char OVIE:1;
            unsigned char CCLR:2;
            unsigned char :3;
        } BIT;
    } TCR;
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :3;
            unsigned char ADTE:1;
            unsigned char OSB:2;
            unsigned char OSA:2;
        } BIT;
    } TCSR;
    char           wk1[1];
    unsigned char  TCORA;
    char           wk2[1];
    unsigned char  TCORB;
    char           wk3[1];
    unsigned char  TCNT;
    char           wk4[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TMRIS:1;
            unsigned char :2;
            unsigned char CSS:2;
            unsigned char CKS:3;
        } BIT;
    } TCCR;
};

struct st_tmr1 {
    union {
        unsigned char BYTE;
        struct {
            unsigned char CMIEB:1;
            unsigned char CMIEA:1;
            unsigned char OVIE:1;
            unsigned char CCLR:2;
            unsigned char :3;
        } BIT;
    } TCR;
    char           wk0[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char :4;
            unsigned char OSB:2;
            unsigned char OSA:2;
        } BIT;
    } TCSR;
    char           wk1[1];
    unsigned char  TCORA;
    char           wk2[1];
    unsigned char  TCORB;
    char           wk3[1];
    unsigned char  TCNT;
    char           wk4[1];
    union {
        unsigned char BYTE;
        struct {
            unsigned char TMRIS:1;
            unsigned char :2;
            unsigned char CSS:2;
            unsigned char CKS:3;
        } BIT;
    } TCCR;
};

struct st_tmr01 {
    unsigned short TCORA;
    unsigned short TCORB;
    unsigned short TCNT;
    unsigned short TCCR;
};

enum enum_ir {
IR_BSC_BUSERR=16,IR_FCU_FRDYI=23,
IR_ICU_SWINT=27,
IR_CMT0_CMI0,IR_CMT1_CMI1,
IR_CMT2_CMI2,IR_CMT3_CMI3,
IR_CAC_FERRF,IR_CAC_MENDF,IR_CAC_OVFF,
IR_RSPI0_SPEI0=44,IR_RSPI0_SPRI0,IR_RSPI0_SPTI0,IR_RSPI0_SPII0,
IR_DOC_DOPCF=57,
IR_ICU_IRQ0=64,IR_ICU_IRQ1,IR_ICU_IRQ2,IR_ICU_IRQ3,IR_ICU_IRQ4,IR_ICU_IRQ5,
IR_LVD_LVD1=88,IR_LVD_LVD2,
IR_S12AD_S12ADI=102,IR_S12AD_GBADI,
IR_CMPC0_CMPC0=108,
IR_CMPC1_CMPC1,
IR_CMPC2_CMPC2,
IR_MTU0_TGIA0=114,IR_MTU0_TGIB0,IR_MTU0_TGIC0,IR_MTU0_TGID0,IR_MTU0_TCIV0,IR_MTU0_TGIE0,IR_MTU0_TGIF0,
IR_MTU1_TGIA1,IR_MTU1_TGIB1,IR_MTU1_TCIV1,IR_MTU1_TCIU1,
IR_MTU2_TGIA2,IR_MTU2_TGIB2,IR_MTU2_TCIV2,IR_MTU2_TCIU2,
IR_MTU3_TGIA3,IR_MTU3_TGIB3,IR_MTU3_TGIC3,IR_MTU3_TGID3,IR_MTU3_TCIV3,
IR_MTU4_TGIA4,IR_MTU4_TGIB4,IR_MTU4_TGIC4,IR_MTU4_TGID4,IR_MTU4_TCIV4,
IR_MTU5_TGIU5,IR_MTU5_TGIV5,IR_MTU5_TGIW5,
IR_POE_OEI1=168,IR_POE_OEI3=170,IR_POE_OEI4,
IR_TMR0_CMIA0=174,IR_TMR0_CMIB0,IR_TMR0_OVI0,
IR_TMR1_CMIA1,IR_TMR1_CMIB1,IR_TMR1_OVI1,
IR_TMR2_CMIA2,IR_TMR2_CMIB2,IR_TMR2_OVI2,
IR_TMR3_CMIA3,IR_TMR3_CMIB3,IR_TMR3_OVI3,
IR_SCI1_ERI1=218,IR_SCI1_RXI1,IR_SCI1_TXI1,IR_SCI1_TEI1,
IR_SCI5_ERI5,IR_SCI5_RXI5,IR_SCI5_TXI5,IR_SCI5_TEI5,
IR_RIIC0_EEI0=246,IR_RIIC0_RXI0,IR_RIIC0_TXI0,IR_RIIC0_TEI0
};

enum enum_dtce {
DTCE_ICU_SWINT=27,
DTCE_CMT0_CMI0,DTCE_CMT1_CMI1,
DTCE_CMT2_CMI2,DTCE_CMT3_CMI3,
DTCE_RSPI0_SPRI0=45,DTCE_RSPI0_SPTI0,
DTCE_ICU_IRQ0=64,DTCE_ICU_IRQ1,DTCE_ICU_IRQ2,DTCE_ICU_IRQ3,DTCE_ICU_IRQ4,DTCE_ICU_IRQ5,
DTCE_S12AD_S12ADI=102,DTCE_S12AD_GBADI,
DTCE_CMPC0_CMPC0=108,
DTCE_CMPC1_CMPC1,
DTCE_CMPC2_CMPC2,
DTCE_MTU0_TGIA0=114,DTCE_MTU0_TGIB0,DTCE_MTU0_TGIC0,DTCE_MTU0_TGID0,
DTCE_MTU1_TGIA1=121,DTCE_MTU1_TGIB1,
DTCE_MTU2_TGIA2=125,DTCE_MTU2_TGIB2,
DTCE_MTU3_TGIA3=129,DTCE_MTU3_TGIB3,DTCE_MTU3_TGIC3,DTCE_MTU3_TGID3,
DTCE_MTU4_TGIA4=134,DTCE_MTU4_TGIB4,DTCE_MTU4_TGIC4,DTCE_MTU4_TGID4,DTCE_MTU4_TCIV4,
DTCE_MTU5_TGIU5,DTCE_MTU5_TGIV5,DTCE_MTU5_TGIW5,
DTCE_TMR0_CMIA0=174,DTCE_TMR0_CMIB0,
DTCE_TMR1_CMIA1=177,DTCE_TMR1_CMIB1,
DTCE_TMR2_CMIA2=180,DTCE_TMR2_CMIB2,
DTCE_TMR3_CMIA3=183,DTCE_TMR3_CMIB3,
DTCE_SCI1_RXI1=219,DTCE_SCI1_TXI1,
DTCE_SCI5_RXI5=223,DTCE_SCI5_TXI5,
DTCE_RIIC0_RXI0=247,DTCE_RIIC0_TXI0
};

enum enum_ier {
IER_BSC_BUSERR=0x02,
IER_FCU_FRDYI=0x02,
IER_ICU_SWINT=0x03,
IER_CMT0_CMI0=0x03,IER_CMT1_CMI1=0x03,
IER_CMT2_CMI2=0x03,IER_CMT3_CMI3=0x03,
IER_CAC_FERRF=0x04,IER_CAC_MENDF=0x04,IER_CAC_OVFF=0x04,
IER_RSPI0_SPEI0=0x05,IER_RSPI0_SPRI0=0x05,IER_RSPI0_SPTI0=0x05,IER_RSPI0_SPII0=0x05,
IER_DOC_DOPCF=0x07,
IER_ICU_IRQ0=0x08,IER_ICU_IRQ1=0x08,IER_ICU_IRQ2=0x08,IER_ICU_IRQ3=0x08,IER_ICU_IRQ4=0x08,IER_ICU_IRQ5=0x08,
IER_LVD_LVD1=0x0B,IER_LVD_LVD2=0x0B,
IER_S12AD_S12ADI=0x0C,IER_S12AD_GBADI=0x0C,
IER_CMPC0_CMPC0=0x0D,
IER_CMPC1_CMPC1=0x0D,
IER_CMPC2_CMPC2=0x0D,
IER_MTU0_TGIA0=0x0E,IER_MTU0_TGIB0=0x0E,IER_MTU0_TGIC0=0x0E,IER_MTU0_TGID0=0x0E,IER_MTU0_TCIV0=0x0E,IER_MTU0_TGIE0=0x0E,IER_MTU0_TGIF0=0x0F,
IER_MTU1_TGIA1=0x0F,IER_MTU1_TGIB1=0x0F,IER_MTU1_TCIV1=0x0F,IER_MTU1_TCIU1=0x0F,
IER_MTU2_TGIA2=0x0F,IER_MTU2_TGIB2=0x0F,IER_MTU2_TCIV2=0x0F,IER_MTU2_TCIU2=0x10,
IER_MTU3_TGIA3=0x10,IER_MTU3_TGIB3=0x10,IER_MTU3_TGIC3=0x10,IER_MTU3_TGID3=0x10,IER_MTU3_TCIV3=0x10,
IER_MTU4_TGIA4=0x10,IER_MTU4_TGIB4=0x10,IER_MTU4_TGIC4=0x11,IER_MTU4_TGID4=0x11,IER_MTU4_TCIV4=0x11,
IER_MTU5_TGIU5=0x11,IER_MTU5_TGIV5=0x11,IER_MTU5_TGIW5=0x11,
IER_POE_OEI1=0x15,IER_POE_OEI3=0x15,IER_POE_OEI4=0x15,
IER_TMR0_CMIA0=0x15,IER_TMR0_CMIB0=0x15,IER_TMR0_OVI0=0x16,
IER_TMR1_CMIA1=0x16,IER_TMR1_CMIB1=0x16,IER_TMR1_OVI1=0x16,
IER_TMR2_CMIA2=0x16,IER_TMR2_CMIB2=0x16,IER_TMR2_OVI2=0x16,
IER_TMR3_CMIA3=0x16,IER_TMR3_CMIB3=0x17,IER_TMR3_OVI3=0x17,
IER_SCI1_ERI1=0x1B,IER_SCI1_RXI1=0x1B,IER_SCI1_TXI1=0x1B,IER_SCI1_TEI1=0x1B,
IER_SCI5_ERI5=0x1B,IER_SCI5_RXI5=0x1B,IER_SCI5_TXI5=0x1C,IER_SCI5_TEI5=0x1C,
IER_RIIC0_EEI0=0x1E,IER_RIIC0_RXI0=0x1E,IER_RIIC0_TXI0=0x1F,IER_RIIC0_TEI0=0x1F
};

enum enum_ipr {
IPR_BSC_BUSERR=0,
IPR_FCU_FRDYI=2,
IPR_ICU_SWINT=3,
IPR_CMT0_CMI0=4,IPR_CMT1_CMI1=5,
IPR_CMT2_CMI2=6,IPR_CMT3_CMI3=7,
IPR_CAC_FERRF=32,IPR_CAC_MENDF=33,IPR_CAC_OVFF=34,
IPR_RSPI0_SPEI0=44,IPR_RSPI0_SPRI0=44,IPR_RSPI0_SPTI0=44,IPR_RSPI0_SPII0=44,
IPR_DOC_DOPCF=57,
IPR_ICU_IRQ0=64,IPR_ICU_IRQ1=65,IPR_ICU_IRQ2=66,IPR_ICU_IRQ3=67,IPR_ICU_IRQ4=68,IPR_ICU_IRQ5=69,
IPR_LVD_LVD1=88,IPR_LVD_LVD2=89,
IPR_S12AD_S12ADI=102,IPR_S12AD_GBADI=103,
IPR_CMPC0_CMPC0=108,
IPR_CMPC1_CMPC1=109,
IPR_CMPC2_CMPC2=110,
IPR_MTU0_TGIA0=114,IPR_MTU0_TGIB0=114,IPR_MTU0_TGIC0=114,IPR_MTU0_TGID0=114,IPR_MTU0_TCIV0=118,IPR_MTU0_TGIE0=118,IPR_MTU0_TGIF0=118,
IPR_MTU1_TGIA1=121,IPR_MTU1_TGIB1=121,IPR_MTU1_TCIV1=123,IPR_MTU1_TCIU1=123,
IPR_MTU2_TGIA2=125,IPR_MTU2_TGIB2=125,IPR_MTU2_TCIV2=127,IPR_MTU2_TCIU2=127,
IPR_MTU3_TGIA3=129,IPR_MTU3_TGIB3=129,IPR_MTU3_TGIC3=129,IPR_MTU3_TGID3=129,IPR_MTU3_TCIV3=133,
IPR_MTU4_TGIA4=134,IPR_MTU4_TGIB4=134,IPR_MTU4_TGIC4=134,IPR_MTU4_TGID4=134,IPR_MTU4_TCIV4=138,
IPR_MTU5_TGIU5=139,IPR_MTU5_TGIV5=139,IPR_MTU5_TGIW5=139,
IPR_POE_OEI1=168,IPR_POE_OEI3=168,IPR_POE_OEI4=168,
IPR_TMR0_CMIA0=174,IPR_TMR0_CMIB0=174,IPR_TMR0_OVI0=174,
IPR_TMR1_CMIA1=177,IPR_TMR1_CMIB1=177,IPR_TMR1_OVI1=177,
IPR_TMR2_CMIA2=180,IPR_TMR2_CMIB2=180,IPR_TMR2_OVI2=180,
IPR_TMR3_CMIA3=183,IPR_TMR3_CMIB3=183,IPR_TMR3_OVI3=183,
IPR_SCI1_ERI1=218,IPR_SCI1_RXI1=218,IPR_SCI1_TXI1=218,IPR_SCI1_TEI1=218,
IPR_SCI5_ERI5=222,IPR_SCI5_RXI5=222,IPR_SCI5_TXI5=222,IPR_SCI5_TEI5=222,
IPR_RIIC0_EEI0=246,IPR_RIIC0_RXI0=247,IPR_RIIC0_TXI0=248,IPR_RIIC0_TEI0=249,
IPR_BSC_=0,
IPR_FCU_=2,
IPR_RSPI0_=44,
IPR_DOC_=57,
IPR_CMPC0_=108,
IPR_CMPC1_=109,
IPR_CMPC2_=110,
IPR_MTU1_TGI=121,
IPR_MTU1_TCI=123,
IPR_MTU2_TGI=125,
IPR_MTU2_TCI=127,
IPR_MTU3_TGI=129,
IPR_MTU4_TGI=134,
IPR_MTU5_=139,
IPR_MTU5_TGI=139,
IPR_POE_=168,
IPR_POE_OEI=168,
IPR_TMR0_=174,
IPR_TMR1_=177,
IPR_TMR2_=180,
IPR_TMR3_=183,
IPR_SCI1_=218,
IPR_SCI5_=222
};

#define    IEN_BSC_BUSERR        IEN0
#define    IEN_FCU_FRDYI        IEN7
#define    IEN_ICU_SWINT        IEN3
#define    IEN_CMT0_CMI0        IEN4
#define    IEN_CMT1_CMI1        IEN5
#define    IEN_CMT2_CMI2        IEN6
#define    IEN_CMT3_CMI3        IEN7
#define    IEN_CAC_FERRF        IEN0
#define    IEN_CAC_MENDF        IEN1
#define    IEN_CAC_OVFF        IEN2
#define    IEN_RSPI0_SPEI0        IEN4
#define    IEN_RSPI0_SPRI0        IEN5
#define    IEN_RSPI0_SPTI0        IEN6
#define    IEN_RSPI0_SPII0        IEN7
#define    IEN_DOC_DOPCF        IEN1
#define    IEN_ICU_IRQ0        IEN0
#define    IEN_ICU_IRQ1        IEN1
#define    IEN_ICU_IRQ2        IEN2
#define    IEN_ICU_IRQ3        IEN3
#define    IEN_ICU_IRQ4        IEN4
#define    IEN_ICU_IRQ5        IEN5
#define    IEN_LVD_LVD1        IEN0
#define    IEN_LVD_LVD2        IEN1
#define    IEN_S12AD_S12ADI    IEN6
#define    IEN_S12AD_GBADI        IEN7
#define    IEN_CMPC0_CMPC0        IEN4
#define    IEN_CMPC1_CMPC1        IEN5
#define    IEN_CMPC2_CMPC2        IEN6
#define    IEN_MTU0_TGIA0        IEN2
#define    IEN_MTU0_TGIB0        IEN3
#define    IEN_MTU0_TGIC0        IEN4
#define    IEN_MTU0_TGID0        IEN5
#define    IEN_MTU0_TCIV0        IEN6
#define    IEN_MTU0_TGIE0        IEN7
#define    IEN_MTU0_TGIF0        IEN0
#define    IEN_MTU1_TGIA1        IEN1
#define    IEN_MTU1_TGIB1        IEN2
#define    IEN_MTU1_TCIV1        IEN3
#define    IEN_MTU1_TCIU1        IEN4
#define    IEN_MTU2_TGIA2        IEN5
#define    IEN_MTU2_TGIB2        IEN6
#define    IEN_MTU2_TCIV2        IEN7
#define    IEN_MTU2_TCIU2        IEN0
#define    IEN_MTU3_TGIA3        IEN1
#define    IEN_MTU3_TGIB3        IEN2
#define    IEN_MTU3_TGIC3        IEN3
#define    IEN_MTU3_TGID3        IEN4
#define    IEN_MTU3_TCIV3        IEN5
#define    IEN_MTU4_TGIA4        IEN6
#define    IEN_MTU4_TGIB4        IEN7
#define    IEN_MTU4_TGIC4        IEN0
#define    IEN_MTU4_TGID4        IEN1
#define    IEN_MTU4_TCIV4        IEN2
#define    IEN_MTU5_TGIU5        IEN3
#define    IEN_MTU5_TGIV5        IEN4
#define    IEN_MTU5_TGIW5        IEN5
#define    IEN_POE_OEI1        IEN0
#define    IEN_POE_OEI3        IEN2
#define    IEN_POE_OEI4        IEN3
#define    IEN_TMR0_CMIA0        IEN6
#define    IEN_TMR0_CMIB0        IEN7
#define    IEN_TMR0_OVI0        IEN0
#define    IEN_TMR1_CMIA1        IEN1
#define    IEN_TMR1_CMIB1        IEN2
#define    IEN_TMR1_OVI1        IEN3
#define    IEN_TMR2_CMIA2        IEN4
#define    IEN_TMR2_CMIB2        IEN5
#define    IEN_TMR2_OVI2        IEN6
#define    IEN_TMR3_CMIA3        IEN7
#define    IEN_TMR3_CMIB3        IEN0
#define    IEN_TMR3_OVI3        IEN1
#define    IEN_SCI1_ERI1        IEN2
#define    IEN_SCI1_RXI1        IEN3
#define    IEN_SCI1_TXI1        IEN4
#define    IEN_SCI1_TEI1        IEN5
#define    IEN_SCI5_ERI5        IEN6
#define    IEN_SCI5_RXI5        IEN7
#define    IEN_SCI5_TXI5        IEN0
#define    IEN_SCI5_TEI5        IEN1
#define    IEN_RIIC0_EEI0        IEN6
#define    IEN_RIIC0_RXI0        IEN7
#define    IEN_RIIC0_TXI0        IEN0
#define    IEN_RIIC0_TEI0        IEN1

#define    VECT_BSC_BUSERR        16
#define    VECT_FCU_FRDYI        23
#define    VECT_ICU_SWINT        27
#define    VECT_CMT0_CMI0        28
#define    VECT_CMT1_CMI1        29
#define    VECT_CMT2_CMI2        30
#define    VECT_CMT3_CMI3        31
#define    VECT_CAC_FERRF        32
#define    VECT_CAC_MENDF        33
#define    VECT_CAC_OVFF        34
#define    VECT_RSPI0_SPEI0    44
#define    VECT_RSPI0_SPRI0    45
#define    VECT_RSPI0_SPTI0    46
#define    VECT_RSPI0_SPII0    47
#define    VECT_DOC_DOPCF        57
#define    VECT_ICU_IRQ0        64
#define    VECT_ICU_IRQ1        65
#define    VECT_ICU_IRQ2        66
#define    VECT_ICU_IRQ3        67
#define    VECT_ICU_IRQ4        68
#define    VECT_ICU_IRQ5        69
#define    VECT_LVD_LVD1        88
#define    VECT_LVD_LVD2        89
#define    VECT_S12AD_S12ADI    102
#define    VECT_S12AD_GBADI    103
#define    VECT_CMPC0_CMPC0    108
#define    VECT_CMPC1_CMPC1    109
#define    VECT_CMPC2_CMPC2    110
#define    VECT_MTU0_TGIA0        114
#define    VECT_MTU0_TGIB0        115
#define    VECT_MTU0_TGIC0        116
#define    VECT_MTU0_TGID0        117
#define    VECT_MTU0_TCIV0        118
#define    VECT_MTU0_TGIE0        119
#define    VECT_MTU0_TGIF0        120
#define    VECT_MTU1_TGIA1        121
#define    VECT_MTU1_TGIB1        122
#define    VECT_MTU1_TCIV1        123
#define    VECT_MTU1_TCIU1        124
#define    VECT_MTU2_TGIA2        125
#define    VECT_MTU2_TGIB2        126
#define    VECT_MTU2_TCIV2        127
#define    VECT_MTU2_TCIU2        128
#define    VECT_MTU3_TGIA3        129
#define    VECT_MTU3_TGIB3        130
#define    VECT_MTU3_TGIC3        131
#define    VECT_MTU3_TGID3        132
#define    VECT_MTU3_TCIV3        133
#define    VECT_MTU4_TGIA4        134
#define    VECT_MTU4_TGIB4        135
#define    VECT_MTU4_TGIC4        136
#define    VECT_MTU4_TGID4        137
#define    VECT_MTU4_TCIV4        138
#define    VECT_MTU5_TGIU5        139
#define    VECT_MTU5_TGIV5        140
#define    VECT_MTU5_TGIW5        141
#define    VECT_POE_OEI1        168
#define    VECT_POE_OEI3        170
#define    VECT_POE_OEI4        171
#define    VECT_TMR0_CMIA0        174
#define    VECT_TMR0_CMIB0        175
#define    VECT_TMR0_OVI0        176
#define    VECT_TMR1_CMIA1        177
#define    VECT_TMR1_CMIB1        178
#define    VECT_TMR1_OVI1        179
#define    VECT_TMR2_CMIA2        180
#define    VECT_TMR2_CMIB2        181
#define    VECT_TMR2_OVI2        182
#define    VECT_TMR3_CMIA3        183
#define    VECT_TMR3_CMIB3        184
#define    VECT_TMR3_OVI3        185
#define    VECT_SCI1_ERI1        218
#define    VECT_SCI1_RXI1        219
#define    VECT_SCI1_TXI1        220
#define    VECT_SCI1_TEI1        221
#define    VECT_SCI5_ERI5        222
#define    VECT_SCI5_RXI5        223
#define    VECT_SCI5_TXI5        224
#define    VECT_SCI5_TEI5        225
#define    VECT_RIIC0_EEI0        246
#define    VECT_RIIC0_RXI0        247
#define    VECT_RIIC0_TXI0        248
#define    VECT_RIIC0_TEI0        249

#define    MSTP_DTC    SYSTEM.MSTPCRA.BIT.MSTPA28
#define    MSTP_DA        SYSTEM.MSTPCRA.BIT.MSTPA19
#define    MSTP_S12AD    SYSTEM.MSTPCRA.BIT.MSTPA17
#define    MSTP_CMT0    SYSTEM.MSTPCRA.BIT.MSTPA15
#define    MSTP_CMT1    SYSTEM.MSTPCRA.BIT.MSTPA15
#define    MSTP_CMT2    SYSTEM.MSTPCRA.BIT.MSTPA14
#define    MSTP_CMT3    SYSTEM.MSTPCRA.BIT.MSTPA14
#define    MSTP_MTU    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU0    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU1    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU2    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU3    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU4    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_MTU5    SYSTEM.MSTPCRA.BIT.MSTPA9
#define    MSTP_TMR0    SYSTEM.MSTPCRA.BIT.MSTPA5
#define    MSTP_TMR1    SYSTEM.MSTPCRA.BIT.MSTPA5
#define    MSTP_TMR01    SYSTEM.MSTPCRA.BIT.MSTPA5
#define    MSTP_TMR2    SYSTEM.MSTPCRA.BIT.MSTPA4
#define    MSTP_TMR3    SYSTEM.MSTPCRA.BIT.MSTPA4
#define    MSTP_TMR23    SYSTEM.MSTPCRA.BIT.MSTPA4
#define    MSTP_SCI1    SYSTEM.MSTPCRB.BIT.MSTPB30
#define    MSTP_SMCI1    SYSTEM.MSTPCRB.BIT.MSTPB30
#define    MSTP_SCI5    SYSTEM.MSTPCRB.BIT.MSTPB26
#define    MSTP_SMCI5    SYSTEM.MSTPCRB.BIT.MSTPB26
#define    MSTP_CRC    SYSTEM.MSTPCRB.BIT.MSTPB23
#define    MSTP_RIIC0    SYSTEM.MSTPCRB.BIT.MSTPB21
#define    MSTP_RSPI0    SYSTEM.MSTPCRB.BIT.MSTPB17
#define    MSTP_CMPC0    SYSTEM.MSTPCRB.BIT.MSTPB10
#define    MSTP_CMPC1    SYSTEM.MSTPCRB.BIT.MSTPB10
#define    MSTP_CMPC2    SYSTEM.MSTPCRB.BIT.MSTPB10
#define    MSTP_DOC    SYSTEM.MSTPCRB.BIT.MSTPB6
#define    MSTP_CAC    SYSTEM.MSTPCRC.BIT.MSTPC19
#define    MSTP_RAM0    SYSTEM.MSTPCRC.BIT.MSTPC0

#define    __IR( x )        ICU.IR[ IR ## x ].BIT.IR
#define     _IR( x )        __IR( x )
#define      IR( x , y )    _IR( _ ## x ## _ ## y )
#define    __DTCE( x )        ICU.DTCER[ DTCE ## x ].BIT.DTCE
#define     _DTCE( x )        __DTCE( x )
#define      DTCE( x , y )    _DTCE( _ ## x ## _ ## y )
#define    __IEN( x )        ICU.IER[ IER ## x ].BIT.IEN ## x
#define     _IEN( x )        __IEN( x )
#define      IEN( x , y )    _IEN( _ ## x ## _ ## y )
#define    __IPR( x )        ICU.IPR[ IPR ## x ].BIT.IPR
#define     _IPR( x )        __IPR( x )
#define      IPR( x , y )    _IPR( _ ## x ## _ ## y )
#define    __VECT( x )        VECT ## x
#define     _VECT( x )        __VECT( x )
#define      VECT( x , y )    _VECT( _ ## x ## _ ## y )
#define    __MSTP( x )        MSTP ## x
#define     _MSTP( x )        __MSTP( x )
#define      MSTP( x )        _MSTP( _ ## x )

#define    BSC        (*(volatile struct st_bsc        __evenaccess *)0x81300)
#define    CAC        (*(volatile struct st_cac        __evenaccess *)0x8B000)
#define    CMPC0    (*(volatile struct st_cmpc0      __evenaccess *)0xA0C80)
#define    CMPC1    (*(volatile struct st_cmpc1      __evenaccess *)0xA0CA0)
#define    CMPC2    (*(volatile struct st_cmpc1      __evenaccess *)0xA0CC0)
#define    CMT        (*(volatile struct st_cmt        __evenaccess *)0x88000)
#define    CMT0    (*(volatile struct st_cmt0       __evenaccess *)0x88002)
#define    CMT1    (*(volatile struct st_cmt0       __evenaccess *)0x88008)
#define    CMT2    (*(volatile struct st_cmt0       __evenaccess *)0x88012)
#define    CMT3    (*(volatile struct st_cmt0       __evenaccess *)0x88018)
#define    CRC        (*(volatile struct st_crc        __evenaccess *)0x88280)
#define    DA        (*(volatile struct st_da         __evenaccess *)0x880C0)
#define    DOC        (*(volatile struct st_doc        __evenaccess *)0x8B080)
#define    DTC        (*(volatile struct st_dtc        __evenaccess *)0x82400)
#define    FLASH    (*(volatile struct st_flash      __evenaccess *)0x7FC100)
#define    FLASHCONST        (*(volatile struct st_flashconst __evenaccess *)0x7FC350)
#define    ICU        (*(volatile struct st_icu        __evenaccess *)0x87000)
#define    IWDT    (*(volatile struct st_iwdt       __evenaccess *)0x88030)
#define    MPC        (*(volatile struct st_mpc        __evenaccess *)0x8C11F)
#define    MPU        (*(volatile struct st_mpu        __evenaccess *)0x86400)
#define    MTU        (*(volatile struct st_mtu        __evenaccess *)0xC120A)
#define    MTU0    (*(volatile struct st_mtu0       __evenaccess *)0xC1290)
#define    MTU1    (*(volatile struct st_mtu1       __evenaccess *)0xC1290)
#define    MTU2    (*(volatile struct st_mtu2       __evenaccess *)0xC1292)
#define    MTU3    (*(volatile struct st_mtu3       __evenaccess *)0xC1200)
#define    MTU4    (*(volatile struct st_mtu4       __evenaccess *)0xC1200)
#define    MTU5    (*(volatile struct st_mtu5       __evenaccess *)0xC1294)
#define    POE        (*(volatile struct st_poe        __evenaccess *)0x8C4C0)
#define    PORT0    (*(volatile struct st_port0      __evenaccess *)0x8C000)
#define    PORT1    (*(volatile struct st_port1      __evenaccess *)0x8C001)
#define    PORT2    (*(volatile struct st_port2      __evenaccess *)0x8C002)
#define    PORT3    (*(volatile struct st_port3      __evenaccess *)0x8C003)
#define    PORT4    (*(volatile struct st_port4      __evenaccess *)0x8C004)
#define    PORT7    (*(volatile struct st_port7      __evenaccess *)0x8C007)
#define    PORT9    (*(volatile struct st_port9      __evenaccess *)0x8C009)
#define    PORTA    (*(volatile struct st_porta      __evenaccess *)0x8C00A)
#define    PORTB    (*(volatile struct st_portb      __evenaccess *)0x8C00B)
#define    PORTD    (*(volatile struct st_portd      __evenaccess *)0x8C00D)
#define    PORTE    (*(volatile struct st_porte      __evenaccess *)0x8C04E)
#define    RIIC0    (*(volatile struct st_riic       __evenaccess *)0x88300)
#define    RSPI0    (*(volatile struct st_rspi       __evenaccess *)0x88380)
#define    S12AD    (*(volatile struct st_s12ad      __evenaccess *)0x89000)
#define    SCI1    (*(volatile struct st_sci        __evenaccess *)0x8A020)
#define    SCI5    (*(volatile struct st_sci        __evenaccess *)0x8A0A0)
#define    SMCI1    (*(volatile struct st_smci       __evenaccess *)0x8A020)
#define    SMCI5    (*(volatile struct st_smci       __evenaccess *)0x8A0A0)
#define    SYSTEM    (*(volatile struct st_system     __evenaccess *)0x80000)
#define    TMR0    (*(volatile struct st_tmr0       __evenaccess *)0x88200)
#define    TMR1    (*(volatile struct st_tmr1       __evenaccess *)0x88201)
#define    TMR2    (*(volatile struct st_tmr0       __evenaccess *)0x88210)
#define    TMR3    (*(volatile struct st_tmr1       __evenaccess *)0x88211)
#define    TMR01    (*(volatile struct st_tmr01      __evenaccess *)0x88204)
#define    TMR23    (*(volatile struct st_tmr01      __evenaccess *)0x88214)
#pragma bit_order
#pragma packoption
#endif