/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_ctrl_mcu.h
* Description : Definitions for processing MCU control
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

#ifndef R_MTR_CTRL_MCU_H
#define R_MTR_CTRL_MCU_H

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include "r_mtr_config.h"

#if     defined(RX23T_MRSSK)
    #include "r_mtr_ctrl_rx23t.h"
#elif   defined(RX24T_MRSSK)
    #include "r_mtr_ctrl_rx24t.h"
#elif   defined(RX24U_MRSSK)
    #include "r_mtr_ctrl_rx24u.h"
#else
    #error Please select a valid CPU board by defining a <MCU>_<MRSSK> macro in r_mtr_config.h
#endif

/***********************************************************************************************************************
* Global function definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
* Function Name : R_MTR_InitHardware
* Description   : Initialize peripheral functions
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void R_MTR_InitHardware(void);

/***********************************************************************************************************************
* Function Name : R_MTR_InitBoardUi
* Description   : Initializes peripheral function for board user interface
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void R_MTR_InitBoardUi(void);

/***********************************************************************************************************************
* Function Name : R_MTR_ClearWdt
* Description   : Clears Watch Dog Timer
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void R_MTR_ClearWdt(void);

/***********************************************************************************************************************
* Function Name : mtr_encd_interrupt_enable
* Description   : Enables encoder interrupt
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_encd_interrupt_enable(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_encd_interrupt_disable
* Description   : Disables encoder interrupt
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_encd_interrupt_disable(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_irq_interrupt_enable
* Description   : Enables external(Hall) interrupt
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_irq_interrupt_enable(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_irq_interrupt_disable
* Description   : Disables external(Hall) interrupt
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_irq_interrupt_disable(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_ctrl_start
* Description   : Starts PWM output
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_ctrl_start(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_ctrl_stop
* Description   : Disable PWM output to stop motor control
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_ctrl_stop(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_get_vr1_adc
* Description   : Gets the A/D conversion result for VR1
* Arguments     : None
* Return Value  : A/D converted value
***********************************************************************************************************************/
uint16_t mtr_get_vr1_adc(void);

/***********************************************************************************************************************
* Function Name : mtr_inv_set_uvw
* Description   : PWM duty setting
* Arguments     : f4_duty_u - The duty cycle of Phase-U (0.0 - 1.0);
*                 f4_duty_v - The duty cycle of Phase-V (0.0 - 1.0);
*                 f4_duty_w - The duty cycle of Phase-W (0.0 - 1.0);
*                 u1_id     - The ID of motor connector
* Return Value  : None
***********************************************************************************************************************/
void mtr_inv_set_uvw(float f4_duty_u, float f4_duty_v, float f4_duty_w, uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_get_current_adc
* Description   : Gets the A/D conversion result for Iu,Iw
* Arguments     : f4_iu_ad - Where to store the A/D conversion result of U-phase current
*                 f4_iw_ad - Where to store the A/D conversion result of W-phase current
*                 u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_get_current_adc(float *f4_iu_ad, float *f4_iw_ad, uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_get_vdc_adc
* Description   : A/D conversion for Vdc
* Arguments     : u1_id - Motor ID
* Return Value  : A/D converted value
***********************************************************************************************************************/
float mtr_get_vdc_adc(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_speed_calc_timer_start
* Description   : Starts speed calculation timer
* Arguments     : u1_id - Motor ID
* Return Value  : None
***********************************************************************************************************************/
void mtr_speed_calc_timer_start(uint8_t u1_id);

/***********************************************************************************************************************
* Function Name : mtr_clear_oc_flag
* Description   : Clears forced cutoff flag (detect over current);
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void mtr_clear_oc_flag(void);

#endif /* R_MTR_CTRL_MCU_H */
