/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt_carrier.c
* Description : The carrier interrupt handler of FOC
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Standard library headers */
#include <stdint.h>
#include <machine.h>
#include <math.h>

/* Main associated header file */
#include "r_mtr_foc_control_encd_position.h"

/* Project headers */
#include "r_mtr_common.h"
#include "r_mtr_filter.h"
#include "r_mtr_pi_control.h"
#include "r_mtr_transform.h"
#include "r_mtr_mod.h"
#include "r_mtr_parameter.h"
#include "r_mtr_ctrl_mrssk.h"
#include "r_mtr_ctrl_mcu.h"
#include "r_mtr_volt_err_comp.h"




/***********************************************************************************************************************
* Function Name : mtr_foc_interrupt_carrier
* Description   : The carrier interrupt handler of FOC control
* Arguments     : st_foc - The pointer to the FOC data structure
* Return Value  : None
***********************************************************************************************************************/
void mtr_foc_interrupt_carrier(mtr_foc_control_t *st_foc)
{
    /*============================*/
    /*     Current detection      */
    /*============================*/
    mtr_get_current_iuiw(&st_foc->f4_iu_ad, &st_foc->f4_iw_ad, st_foc->u1_id);
setpsw_i();                                             /* Interrupt enable */
    /*============================*/
    /*     Vdc detection          */
    /*============================*/
    st_foc->f4_vdc_ad = mtr_get_vdc(st_foc->u1_id);
    R_MOD_SetVdc(&st_foc->st_mod, st_foc->f4_vdc_ad);

    /*============================*/
    /*     error check            */
    /*============================*/
    mtr_error_check(st_foc);

    /*=============================*/
    /*  current offset adjustment  */
    /*=============================*/
    mtr_current_offset_adjustment(st_foc);

    if (MTR_MODE_ACTIVE == mtr_statemachine_get_status(&st_foc->st_stm))
    {
        /* Calculate offset current values */
        if (MTR_FLG_CLR == st_foc->u1_flag_offset_calc)
        {
            /*==================================*/
            /*    Current offset calibration    */
            /*==================================*/
            mtr_calib_current_offset(st_foc);
        }
        else
        {
            /************************************/
            /*   position & speed calculation   */
            /************************************/
            mtr_encd_pos_speed_calc(st_foc);

            /*=============================================*/
            /*     Coordinate transformation (UVW->dq)   */
            /*=============================================*/
            mtr_transform_uvw_dq_abs(&st_foc->st_rotor_angle, &st_foc->f4_iu_ad, &st_foc->st_cc.f4_id_ad);

            /*====================================*/
            /*     Feedback control (Current)     */
            /*====================================*/
            mtr_foc_current_pi_ctrl(&(st_foc->st_cc));

            /*============================*/
            /*     Decoupling control     */
            /*============================*/
            mtr_foc_current_decoupling(&(st_foc->st_cc), st_foc->st_sc.f4_ref_speed_rad_ctrl, &(st_foc->st_motor));

            /*===================================*/
            /*     speed & angle detection       */
            /*===================================*/
            mtr_angle_speed(st_foc);

            /*======================*/
            /* Limit voltage vector */
            /*======================*/
            mtr_foc_voltage_limit(st_foc);

            /*=================================================*/
            /*     Coordinate transformation (dq->uvw)         */
            /*=================================================*/
            mtr_transform_dq_uvw_abs(&st_foc->st_rotor_angle, &st_foc->st_cc.f4_vd_ref, &st_foc->f4_refu);

            /*====================================*/
            /*     Voltage error compensation     */
            /*====================================*/
            {
#if (USE_VOLT_ERR_COMP == 1)
                float f4_iuvw_ref[3];
                mtr_transform_dq_uvw_abs(&st_foc->st_rotor_angle, &st_foc->st_cc.f4_id_ref, f4_iuvw_ref);
                mtr_volt_err_comp_main(&st_foc->st_volt_comp_p, &st_foc->f4_refu, f4_iuvw_ref, st_foc->f4_vdc_ad);
#endif
            }

            /*==================================*/
            /*     Space vector modulation      */
            /*==================================*/
            R_MOD_Run(&st_foc->st_mod, &(st_foc->f4_refu) ,&(st_foc->f4_modu));

            /*==============================*/
            /*     PWM reference setting    */
            /*==============================*/
            mtr_inv_set_uvw(st_foc->f4_modu, st_foc->f4_modv, st_foc->f4_modw, st_foc->u1_id);
        }
    }
} /* End of function mtr_foc_interrupt_carrier */
