/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt_sensor.c
* Description : Processes of sensor interrupt
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 05.04.2017 1.00
*         : 07.07.2017 1.01
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Main associated header file */
#include "r_mtr_foc_control_encd_position.h"

/* Project headers */
#include "r_mtr_common.h"
#include "iodefine.h"
#include "r_mtr_ctrl_hall.h"
#include "r_mtr_ctrl_encoder.h"
#include "r_mtr_ctrl_mcu.h"

/***********************************************************************************************************************
* Function Name : mtr_angle_adj_hall_interrupt
* Description   : calculate rotor position
* Arguments     : st_foc - The pointer to the FOC data structure
* Return Value  : None
***********************************************************************************************************************/
void mtr_angle_adj_hall_interrupt(mtr_foc_control_t *st_foc)
{
    float    f4_temp;

    if(MTR_MODE_DRIVE == st_foc->u2_run_mode)
    {
        /* integrate encoder counter difference */
        mtr_encd_hs_cnt_diff(&st_foc->st_ehc, st_foc->u1_id);
        /* calculate angle (mechanical) */
        f4_temp = MTR_TWOPI * st_foc->st_ehc.s4_encd_hs_angle_cnt;
        f4_temp = f4_temp * st_foc->st_ec.f4_encd_cpr_mech_inv;
        st_foc->st_hc.u1_hall_signal = mtr_get_hall_signal(st_foc->u1_id);     /* get hall signal */
        if(MTR_CW == st_foc->u1_direction)
        {
            st_foc->st_hc.f4_hall_angle_rad =
             mtr_hall_angle_edge_set(st_foc->st_hc.u1_hall_signal, st_foc->st_hc.u1_hall_pre_signal)
             - (f4_temp * st_foc->st_motor.u2_mtr_pp);
        }
        else
        {
            st_foc->st_hc.f4_hall_angle_rad =
             mtr_hall_angle_edge_set(st_foc->st_hc.u1_hall_signal, st_foc->st_hc.u1_hall_pre_signal)
             + (360.0f * MTR_TWOPI_360 - f4_temp) * st_foc->st_motor.u2_mtr_pp;
        }
                                                                               /* hall edge angle set */
        st_foc->st_hc.u1_hall_interrupt_flg = MTR_FLG_SET;
        mtr_hall_error(st_foc, st_foc->st_hc.f4_hall_angle_rad);
        mtr_irq_interrupt_disable(st_foc->u1_id);                              /* hall interrupt desable */
    }
} /* End of function mtr_angle_adj_hall_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_encd_pos_speed_calc_interrupt
* Description   : calculate rotor position and speed
* Arguments     : st_foc - The pointer to the FOC data structure
* Return Value  : None 
***********************************************************************************************************************/
void mtr_encd_pos_speed_calc_interrupt(mtr_foc_control_t *st_foc)
{
    uint16_t u2_temp;
    int16_t  s2_encd_delta_tcnt;
    float    f4_temp_speed_rad_avg, f4_temp0;

    if (MTR_ENCD_ANGLE_ADJ_FIN == st_foc->st_ec.u1_encd_angle_adj_status)
    {
        /* integrate encoder counter difference */
        u2_temp = mtr_get_encd_tcnt(st_foc->u1_id);
        if(MTR_FLG_SET == st_foc->st_ehc.u1_encd_interrupt_on_flag)
        {
            st_foc->st_ec.s4_encd_angle_cnt = st_foc->st_ehc.s4_encd_hs_angle_cnt;
            st_foc->st_ec.u2_encd_pre_phase_cnt = st_foc->st_ehc.u2_encd_hs_pre_phase_cnt;
            st_foc->st_ehc.u1_encd_interrupt_on_flag = MTR_FLG_CLR;
        }
        else
        {
            /* Do Nothing */
        }
        s2_encd_delta_tcnt = st_foc->st_ec.u2_encd_pre_phase_cnt - u2_temp;
        st_foc->st_ec.s4_encd_angle_cnt += (int32_t)s2_encd_delta_tcnt;
        st_foc->st_ec.u2_encd_pre_phase_cnt = u2_temp;

        /*=========================*/
        /*    angle calculation    */
        /*=========================*/
        if (MTR_LOOP_SPEED == st_foc->u1_ctrl_loop_mode)
        {
            /* limit count value to counts of one rotation */
            if (st_foc->st_ec.s4_encd_angle_cnt >= (int32_t)st_foc->st_ec.u2_encd_cpr_mech)
            {
                st_foc->st_ec.s4_encd_angle_cnt -= (int32_t)st_foc->st_ec.u2_encd_cpr_mech;
            }
            else if (st_foc->st_ec.s4_encd_angle_cnt < 0.0f)
            {
                st_foc->st_ec.s4_encd_angle_cnt += (int32_t)st_foc->st_ec.u2_encd_cpr_mech;
            }
            else
            {
                /* Do Nothing */
            }
        }

        /* calculate angle (mechanical) */
        st_foc->st_ec.f4_encd_pos_rad = (MTR_TWOPI * st_foc->st_ec.s4_encd_angle_cnt) * st_foc->st_ec.f4_encd_cpr_mech_inv;

        /*===============================*/
        /*    pulse width calculation    */
        /*===============================*/
        /* calculate integrated pulse width */
        st_foc->st_ec.u2_encd_timer_cap_tcnt =  MTR_ENCD_PLSWIDTH_TCNT;
        u2_temp = (st_foc->st_ec.u2_encd_timer_cap_tcnt - st_foc->st_ec.u2_encd_timer_cap_pre_tcnt);
        st_foc->st_ec.s4_encd_pulse_width_buff += (int32_t)u2_temp;
        st_foc->st_ec.u2_encd_timer_cap_pre_tcnt = st_foc->st_ec.u2_encd_timer_cap_tcnt;
        /* limit pulse width, prevent s4_encd_pulse_width_buff from overflow */
        if (st_foc->st_ec.s4_encd_pulse_width_buff > MTR_ENCD_ZEROSPEED_PW)
        {
            st_foc->st_ec.s4_encd_pulse_width_buff = MTR_ENCD_ZEROSPEED_PW;
        }
        /* push last pulse width to buffer */
        st_foc->st_ec.s4_encd_pulse_width = st_foc->st_ec.s4_encd_pulse_width_buff;
        st_foc->st_ec.s4_encd_pulse_width_buff = 0;
        st_foc->st_ec.s4_encd_pulse_width_sum +=
            st_foc->st_ec.s4_encd_pulse_width - st_foc->st_ec.s4_encd_timer_cnt_buff[st_foc->st_ec.u2_encd_timer_cnt_num];
        st_foc->st_ec.s4_encd_timer_cnt_buff[st_foc->st_ec.u2_encd_timer_cnt_num] = st_foc->st_ec.s4_encd_pulse_width;
        st_foc->st_ec.u2_encd_timer_cnt_num++;
        st_foc->st_ec.u2_encd_timer_cnt_num %= MTR_ENCD_CNTAVG;

        /*=======================*/
        /*    speed averaging    */
        /*=======================*/
        if (st_foc->st_ec.s4_encd_pulse_width_sum != 0)
        {
            /* calculate angle[rad] difference (MTR_ENCD_CNTAVG count of encoder) */
            /* angle[rad] = 2Pi * (Count Difference) / (Count Per Rotation) */
            /* divide angle[rad] by time[s] to calculate speed[rad/s] */
            /* time[s] = pulse_width[count] / (MTU0 Frequency[Hz]) = pulse_width[count]/(PWM Frequency[Hz]) */
            f4_temp0 = st_foc->st_ec.f4_encd_angle_diff * MTR_ENCD_CALC_AVG;
            f4_temp_speed_rad_avg = f4_temp0 / (float)st_foc->st_ec.s4_encd_pulse_width_sum;
            /* get speed direction from encoder position change */
            if (0 > s2_encd_delta_tcnt)
            {
                f4_temp_speed_rad_avg = - f4_temp_speed_rad_avg;
            }
            else if (0 == s2_encd_delta_tcnt)
            {
                if (0.0f > st_foc->st_ec.f4_encd_speed_pre_rad)
                {
                    f4_temp_speed_rad_avg = - f4_temp_speed_rad_avg;
                }
            }
            else
            {
                /* Do Nothing*/
            }
            st_foc->st_ec.f4_encd_speed_pre_rad = st_foc->st_ec.f4_encd_speed_rad;
            st_foc->st_ec.f4_encd_speed_rad = f4_temp_speed_rad_avg;
        }
    }
} /* End of function mtr_encd_pos_speed_calc_interrupt */
